@@ -72,18 +72,32 @@ case "$1" in
     ubsan)
         FSAN='-fsanitize=undefined -fsanitize-undefined-trap-on-error -fno-omit-frame-pointer'
         ;;
+    gprof)
+        # gprof
+        OPTS="$OPTS --enable-profiling"
+        ;;
     "")
         ;;
     *)
-        echo "Usage: $0 [clean|asan|tsan]"
+        echo "Usage: $0 [clean|asan|tsan|ubsan|gprof]"
         exit 1
         ;;
 esac
 
 
+if [[ $1 != clean ]]; then
+    # enable strict C99, C++98 checks.
+    export CFLAGS="$CFLAGS -std=c99"
+    export CXXFLAGS="$CXXFLAGS -std=c++98"
+fi
+
+# enable variable shadow warnings
+#export CFLAGS="$CFLAGS -Wshadow=compatible-local -Wshadow=local"
+#export CXXFLAGS="$CXXFLAGS -Wshadow=compatible-local -Wshadow=local"
+
 # enable pedantic
-#export CFLAGS='-std=c99 -pedantic -Wshadow'
-#export CXXFLAGS='-std=c++98 -pedantic'
+#export CFLAGS='-pedantic'
+#export CXXFLAGS='-pedantic'
 
 if [[ ! -z $FSAN ]]; then
     export CPPFLAGS="$CPPFLAGS $FSAN"
@@ -96,20 +110,14 @@ OPTS="$OPTS --enable-devel"
 # disable optimizations
 OPTS="$OPTS --disable-optimization"
 
-# gprof
-#OPTS="$OPTS --enable-profiling --disable-optimization"
-
 # disable lz4
 #OPTS="$OPTS --disable-lz4"
 
 # disable cyrus-sasl
 #OPTS="$OPTS --disable-sasl"
 
-# enable sharedptr debugging
-#OPTS="$OPTS --enable-sharedptr-debug"
-
 #enable refcnt debugging
 #OPTS="$OPTS --enable-refcnt-debug"
 
-build Development $OPTS
+build Development "$OPTS"
 
