@@ -3,24 +3,24 @@
  *
  * Copyright (c) 2014, Magnus Edenhill
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met: 
- * 
+ * modification, are permitted provided that the following conditions are met:
+ *
  * 1. Redistributions of source code must retain the above copyright notice,
- *    this list of conditions and the following disclaimer. 
+ *    this list of conditions and the following disclaimer.
  * 2. Redistributions in binary form must reproduce the above copyright notice,
  *    this list of conditions and the following disclaimer in the documentation
- *    and/or other materials provided with the distribution. 
- * 
+ *    and/or other materials provided with the distribution.
+ *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
  * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
@@ -63,13 +63,13 @@
 
 
 static volatile sig_atomic_t run = 1;
-static bool exit_eof = false;
-static int eof_cnt = 0;
-static int partition_cnt = 0;
-static int verbosity = 1;
-static long msg_cnt = 0;
-static int64_t msg_bytes = 0;
-static void sigterm (int sig) {
+static bool exit_eof             = false;
+static int eof_cnt               = 0;
+static int partition_cnt         = 0;
+static int verbosity             = 1;
+static long msg_cnt              = 0;
+static int64_t msg_bytes         = 0;
+static void sigterm(int sig) {
   run = 0;
 }
 
@@ -77,81 +77,80 @@ static void sigterm (int sig) {
 /**
  * @brief format a string timestamp from the current time
  */
-static void print_time () {
+static void print_time() {
 #ifndef _WIN32
-        struct timeval tv;
-        char buf[64];
-        gettimeofday(&tv, NULL);
-        strftime(buf, sizeof(buf) - 1, "%Y-%m-%d %H:%M:%S", localtime(&tv.tv_sec));
-        fprintf(stderr, "%s.%03d: ", buf, (int)(tv.tv_usec / 1000));
+  struct timeval tv;
+  char buf[64];
+  gettimeofday(&tv, NULL);
+  strftime(buf, sizeof(buf) - 1, "%Y-%m-%d %H:%M:%S", localtime(&tv.tv_sec));
+  fprintf(stderr, "%s.%03d: ", buf, (int)(tv.tv_usec / 1000));
 #else
-        SYSTEMTIME lt = {0};
-        GetLocalTime(&lt);
-        // %Y-%m-%d %H:%M:%S.xxx:
-        fprintf(stderr, "%04d-%02d-%02d %02d:%02d:%02d.%03d: ",
-            lt.wYear, lt.wMonth, lt.wDay,
-            lt.wHour, lt.wMinute, lt.wSecond, lt.wMilliseconds);
+  SYSTEMTIME lt = {0};
+  GetLocalTime(&lt);
+  // %Y-%m-%d %H:%M:%S.xxx:
+  fprintf(stderr, "%04d-%02d-%02d %02d:%02d:%02d.%03d: ", lt.wYear, lt.wMonth,
+          lt.wDay, lt.wHour, lt.wMinute, lt.wSecond, lt.wMilliseconds);
 #endif
 }
 class ExampleEventCb : public RdKafka::EventCb {
  public:
-  void event_cb (RdKafka::Event &event) {
-
+  void event_cb(RdKafka::Event &event) {
     print_time();
 
-    switch (event.type())
-    {
-      case RdKafka::Event::EVENT_ERROR:
-        if (event.fatal()) {
-          std::cerr << "FATAL ";
-          run = 0;
-        }
-        std::cerr << "ERROR (" << RdKafka::err2str(event.err()) << "): " <<
-            event.str() << std::endl;
-        break;
+    switch (event.type()) {
+    case RdKafka::Event::EVENT_ERROR:
+      if (event.fatal()) {
+        std::cerr << "FATAL ";
+        run = 0;
+      }
+      std::cerr << "ERROR (" << RdKafka::err2str(event.err())
+                << "): " << event.str() << std::endl;
+      break;
 
-      case RdKafka::Event::EVENT_STATS:
-        std::cerr << "\"STATS\": " << event.str() << std::endl;
-        break;
+    case RdKafka::Event::EVENT_STATS:
+      std::cerr << "\"STATS\": " << event.str() << std::endl;
+      break;
 
-      case RdKafka::Event::EVENT_LOG:
-        fprintf(stderr, "LOG-%i-%s: %s\n",
-                event.severity(), event.fac().c_str(), event.str().c_str());
-        break;
+    case RdKafka::Event::EVENT_LOG:
+      fprintf(stderr, "LOG-%i-%s: %s\n", event.severity(), event.fac().c_str(),
+              event.str().c_str());
+      break;
 
-      case RdKafka::Event::EVENT_THROTTLE:
-	std::cerr << "THROTTLED: " << event.throttle_time() << "ms by " <<
-	  event.broker_name() << " id " << (int)event.broker_id() << std::endl;
-	break;
+    case RdKafka::Event::EVENT_THROTTLE:
+      std::cerr << "THROTTLED: " << event.throttle_time() << "ms by "
+                << event.broker_name() << " id " << (int)event.broker_id()
+                << std::endl;
+      break;
 
-      default:
-        std::cerr << "EVENT " << event.type() <<
-            " (" << RdKafka::err2str(event.err()) << "): " <<
-            event.str() << std::endl;
-        break;
+    default:
+      std::cerr << "EVENT " << event.type() << " ("
+                << RdKafka::err2str(event.err()) << "): " << event.str()
+                << std::endl;
+      break;
     }
   }
 };
 
 
 class ExampleRebalanceCb : public RdKafka::RebalanceCb {
-private:
-  static void part_list_print (const std::vector<RdKafka::TopicPartition*>&partitions){
-    for (unsigned int i = 0 ; i < partitions.size() ; i++)
-      std::cerr << partitions[i]->topic() <<
-	"[" << partitions[i]->partition() << "], ";
+ private:
+  static void part_list_print(
+      const std::vector<RdKafka::TopicPartition *> &partitions) {
+    for (unsigned int i = 0; i < partitions.size(); i++)
+      std::cerr << partitions[i]->topic() << "[" << partitions[i]->partition()
+                << "], ";
     std::cerr << "\n";
   }
 
-public:
-  void rebalance_cb (RdKafka::KafkaConsumer *consumer,
-		     RdKafka::ErrorCode err,
-                     std::vector<RdKafka::TopicPartition*> &partitions) {
+ public:
+  void rebalance_cb(RdKafka::KafkaConsumer *consumer,
+                    RdKafka::ErrorCode err,
+                    std::vector<RdKafka::TopicPartition *> &partitions) {
     std::cerr << "RebalanceCb: " << RdKafka::err2str(err) << ": ";
 
     part_list_print(partitions);
 
-    RdKafka::Error *error = NULL;
+    RdKafka::Error *error      = NULL;
     RdKafka::ErrorCode ret_err = RdKafka::ERR_NO_ERROR;
 
     if (err == RdKafka::ERR__ASSIGN_PARTITIONS) {
@@ -165,7 +164,7 @@ public:
         error = consumer->incremental_unassign(partitions);
         partition_cnt -= (int)partitions.size();
       } else {
-        ret_err = consumer->unassign();
+        ret_err       = consumer->unassign();
         partition_cnt = 0;
       }
     }
@@ -176,66 +175,65 @@ public:
       delete error;
     } else if (ret_err)
       std::cerr << "assign failed: " << RdKafka::err2str(ret_err) << "\n";
-
   }
 };
 
 
-void msg_consume(RdKafka::Message* message, void* opaque) {
+void msg_consume(RdKafka::Message *message, void *opaque) {
   switch (message->err()) {
-    case RdKafka::ERR__TIMED_OUT:
-      break;
+  case RdKafka::ERR__TIMED_OUT:
+    break;
 
-    case RdKafka::ERR_NO_ERROR:
-      /* Real message */
-      msg_cnt++;
-      msg_bytes += message->len();
-      if (verbosity >= 3)
-        std::cerr << "Read msg at offset " << message->offset() << std::endl;
-      RdKafka::MessageTimestamp ts;
-      ts = message->timestamp();
-      if (verbosity >= 2 &&
-	  ts.type != RdKafka::MessageTimestamp::MSG_TIMESTAMP_NOT_AVAILABLE) {
-	std::string tsname = "?";
-	if (ts.type == RdKafka::MessageTimestamp::MSG_TIMESTAMP_CREATE_TIME)
-	  tsname = "create time";
-        else if (ts.type == RdKafka::MessageTimestamp::MSG_TIMESTAMP_LOG_APPEND_TIME)
-          tsname = "log append time";
-        std::cout << "Timestamp: " << tsname << " " << ts.timestamp << std::endl;
-      }
-      if (verbosity >= 2 && message->key()) {
-        std::cout << "Key: " << *message->key() << std::endl;
-      }
-      if (verbosity >= 1) {
-        printf("%.*s\n",
-               static_cast<int>(message->len()),
-               static_cast<const char *>(message->payload()));
-      }
-      break;
+  case RdKafka::ERR_NO_ERROR:
+    /* Real message */
+    msg_cnt++;
+    msg_bytes += message->len();
+    if (verbosity >= 3)
+      std::cerr << "Read msg at offset " << message->offset() << std::endl;
+    RdKafka::MessageTimestamp ts;
+    ts = message->timestamp();
+    if (verbosity >= 2 &&
+        ts.type != RdKafka::MessageTimestamp::MSG_TIMESTAMP_NOT_AVAILABLE) {
+      std::string tsname = "?";
+      if (ts.type == RdKafka::MessageTimestamp::MSG_TIMESTAMP_CREATE_TIME)
+        tsname = "create time";
+      else if (ts.type ==
+               RdKafka::MessageTimestamp::MSG_TIMESTAMP_LOG_APPEND_TIME)
+        tsname = "log append time";
+      std::cout << "Timestamp: " << tsname << " " << ts.timestamp << std::endl;
+    }
+    if (verbosity >= 2 && message->key()) {
+      std::cout << "Key: " << *message->key() << std::endl;
+    }
+    if (verbosity >= 1) {
+      printf("%.*s\n", static_cast<int>(message->len()),
+             static_cast<const char *>(message->payload()));
+    }
+    break;
 
-    case RdKafka::ERR__PARTITION_EOF:
-      /* Last message */
-      if (exit_eof && ++eof_cnt == partition_cnt) {
-        std::cerr << "%% EOF reached for all " << partition_cnt <<
-            " partition(s)" << std::endl;
-        run = 0;
-      }
-      break;
-
-    case RdKafka::ERR__UNKNOWN_TOPIC:
-    case RdKafka::ERR__UNKNOWN_PARTITION:
-      std::cerr << "Consume failed: " << message->errstr() << std::endl;
+  case RdKafka::ERR__PARTITION_EOF:
+    /* Last message */
+    if (exit_eof && ++eof_cnt == partition_cnt) {
+      std::cerr << "%% EOF reached for all " << partition_cnt << " partition(s)"
+                << std::endl;
       run = 0;
-      break;
+    }
+    break;
 
-    default:
-      /* Errors */
-      std::cerr << "Consume failed: " << message->errstr() << std::endl;
-      run = 0;
+  case RdKafka::ERR__UNKNOWN_TOPIC:
+  case RdKafka::ERR__UNKNOWN_PARTITION:
+    std::cerr << "Consume failed: " << message->errstr() << std::endl;
+    run = 0;
+    break;
+
+  default:
+    /* Errors */
+    std::cerr << "Consume failed: " << message->errstr() << std::endl;
+    run = 0;
   }
 }
 
-int main (int argc, char **argv) {
+int main(int argc, char **argv) {
   std::string brokers = "localhost";
   std::string errstr;
   std::string topic_str;
@@ -258,7 +256,7 @@ int main (int argc, char **argv) {
   while ((opt = getopt(argc, argv, "g:b:z:qd:eX:AM:qv")) != -1) {
     switch (opt) {
     case 'g':
-      if (conf->set("group.id",  optarg, errstr) != RdKafka::Conf::CONF_OK) {
+      if (conf->set("group.id", optarg, errstr) != RdKafka::Conf::CONF_OK) {
         std::cerr << errstr << std::endl;
         exit(1);
       }
@@ -268,9 +266,9 @@ int main (int argc, char **argv) {
       break;
     case 'z':
       if (conf->set("compression.codec", optarg, errstr) !=
-	  RdKafka::Conf::CONF_OK) {
-	std::cerr << errstr << std::endl;
-	exit(1);
+          RdKafka::Conf::CONF_OK) {
+        std::cerr << errstr << std::endl;
+        exit(1);
       }
       break;
     case 'e':
@@ -286,47 +284,44 @@ int main (int argc, char **argv) {
         exit(1);
       }
       break;
-    case 'X':
-      {
-	char *name, *val;
+    case 'X': {
+      char *name, *val;
 
-	if (!strcmp(optarg, "dump")) {
-	  do_conf_dump = true;
-	  continue;
-	}
-
-	name = optarg;
-	if (!(val = strchr(name, '='))) {
-          std::cerr << "%% Expected -X property=value, not " <<
-              name << std::endl;
-	  exit(1);
-	}
-
-	*val = '\0';
-	val++;
-
-        RdKafka::Conf::ConfResult res = conf->set(name, val, errstr);
-        if (res != RdKafka::Conf::CONF_OK) {
-          std::cerr << errstr << std::endl;
-	  exit(1);
-	}
+      if (!strcmp(optarg, "dump")) {
+        do_conf_dump = true;
+        continue;
       }
+
+      name = optarg;
+      if (!(val = strchr(name, '='))) {
+        std::cerr << "%% Expected -X property=value, not " << name << std::endl;
+        exit(1);
+      }
+
+      *val = '\0';
+      val++;
+
+      RdKafka::Conf::ConfResult res = conf->set(name, val, errstr);
+      if (res != RdKafka::Conf::CONF_OK) {
+        std::cerr << errstr << std::endl;
+        exit(1);
+      }
+    } break;
+
+    case 'q':
+      verbosity--;
       break;
 
-      case 'q':
-        verbosity--;
-        break;
-
-      case 'v':
-        verbosity++;
-        break;
+    case 'v':
+      verbosity++;
+      break;
 
     default:
       goto usage;
     }
   }
 
-  for (; optind < argc ; optind++)
+  for (; optind < argc; optind++)
     topics.push_back(std::string(argv[optind]));
 
   if (topics.empty() || optind != argc) {
@@ -354,19 +349,20 @@ int main (int argc, char **argv) {
             "  -v              Increase verbosity\n"
             "\n"
             "\n",
-	    argv[0],
-	    RdKafka::version_str().c_str(), RdKafka::version(),
-	    RdKafka::get_debug_contexts().c_str());
-	exit(1);
+            argv[0], RdKafka::version_str().c_str(), RdKafka::version(),
+            RdKafka::get_debug_contexts().c_str());
+    exit(1);
   }
 
   if (exit_eof) {
     std::string strategy;
     if (conf->get("partition.assignment.strategy", strategy) ==
-        RdKafka::Conf::CONF_OK && strategy == "cooperative-sticky") {
-      std::cerr << "Error: this example has not been modified to " <<
-        "support -e (exit on EOF) when the partition.assignment.strategy " <<
-        "is set to " << strategy << ": remove -e from the command line\n";
+            RdKafka::Conf::CONF_OK &&
+        strategy == "cooperative-sticky") {
+      std::cerr
+          << "Error: this example has not been modified to "
+          << "support -e (exit on EOF) when the partition.assignment.strategy "
+          << "is set to " << strategy << ": remove -e from the command line\n";
       exit(1);
     }
   }
@@ -392,7 +388,7 @@ int main (int argc, char **argv) {
     std::cout << "# Global config" << std::endl;
 
     for (std::list<std::string>::iterator it = dump->begin();
-         it != dump->end(); ) {
+         it != dump->end();) {
       std::cout << *it << " = ";
       it++;
       std::cout << *it << std::endl;
@@ -414,7 +410,8 @@ int main (int argc, char **argv) {
   /*
    * Create consumer using accumulated global configuration.
    */
-  RdKafka::KafkaConsumer *consumer = RdKafka::KafkaConsumer::create(conf, errstr);
+  RdKafka::KafkaConsumer *consumer =
+      RdKafka::KafkaConsumer::create(conf, errstr);
   if (!consumer) {
     std::cerr << "Failed to create consumer: " << errstr << std::endl;
     exit(1);
@@ -430,8 +427,8 @@ int main (int argc, char **argv) {
    */
   RdKafka::ErrorCode err = consumer->subscribe(topics);
   if (err) {
-    std::cerr << "Failed to subscribe to " << topics.size() << " topics: "
-              << RdKafka::err2str(err) << std::endl;
+    std::cerr << "Failed to subscribe to " << topics.size()
+              << " topics: " << RdKafka::err2str(err) << std::endl;
     exit(1);
   }
 
@@ -454,8 +451,8 @@ int main (int argc, char **argv) {
   consumer->close();
   delete consumer;
 
-  std::cerr << "% Consumed " << msg_cnt << " messages ("
-            << msg_bytes << " bytes)" << std::endl;
+  std::cerr << "% Consumed " << msg_cnt << " messages (" << msg_bytes
+            << " bytes)" << std::endl;
 
   /*
    * Wait for RdKafka to decommission.
