@@ -1,14 +1,14 @@
 #!/bin/bash
 #
-# Build librdkafka on a bare-bone Debian host, such as the microsoft/dotnet:2-sdk
-# Docker image.
+# Build librdkafka on a bare-bone Debian host, such as the
+# mcr.microsoft.com/dotnet/sdk Docker image.
 #
 # Statically linked
 # WITH openssl 1.0, zlib
 # WITHOUT libsasl2, lz4(ext, using builtin instead)
 #
 # Usage (from top-level librdkafka dir):
-#   docker run -it -v $PWD:/v microsoft/dotnet:2-sdk /v/packaging/tools/build-debian.sh /v /v/librdkafka-debian9.tgz
+#   docker run -it -v $PWD:/v mcr.microsoft.com/dotnet/sdk /v/packaging/tools/build-debian.sh /v /v/librdkafka-debian9.tgz
 #
 
 
@@ -28,7 +28,7 @@ fi
 set -u
 
 apt-get update
-apt-get install -y gcc g++ zlib1g-dev python3 git-core make
+apt-get install -y gcc g++ zlib1g-dev python3 git-core make patch
 
 
 # Copy the librdkafka git archive to a new location to avoid messing
@@ -41,6 +41,11 @@ pushd $BUILD_DIR
 DEST_DIR=$PWD/dest
 mkdir -p $DEST_DIR
 
+# Workaround for newer Git not allowing clone directory to be owned by
+# another user (which is a questionable limitation for the read-only archive
+# command..)
+git config --global --add safe.directory /v
+
 (cd $LRK_DIR ; git archive --format tar HEAD) | tar xf -
 
 ./configure --install-deps --disable-gssapi --disable-lz4-ext --enable-static --prefix=$DEST_DIR $CONFIG_ARGS
