@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # Calculate checksums for GitHub release artifacts/assets.
 #
@@ -24,13 +24,14 @@ if __name__ == '__main__':
     print("Release asset checksums:")
 
     for ftype in ["zip", "tar.gz"]:
-        url = "https://github.com/edenhill/librdkafka/archive/{}.{}".format(tag, ftype)
+        url = "https://github.com/edenhill/librdkafka/archive/{}.{}".format(
+            tag, ftype)
 
         h = hashlib.sha256()
 
         r = requests.get(url, stream=True)
         while True:
-            buf = r.raw.read(100*1000)
+            buf = r.raw.read(100 * 1000)
             if len(buf) == 0:
                 break
             h.update(buf)
