@@ -40,14 +40,13 @@ typedef struct rd_avg_s {
                 int64_t minv;
                 int64_t avg;
                 int64_t sum;
-                int     cnt;
+                int cnt;
                 rd_ts_t start;
         } ra_v;
         mtx_t ra_lock;
-        int   ra_enabled;
-        enum {
-                RD_AVG_GAUGE,
-                RD_AVG_COUNTER,
+        int ra_enabled;
+        enum { RD_AVG_GAUGE,
+               RD_AVG_COUNTER,
         } ra_type;
 #if WITH_HDRHISTOGRAM
         rd_hdr_histogram_t *ra_hdr;
@@ -74,18 +73,18 @@ typedef struct rd_avg_s {
 /**
  * @brief Add value \p v to averager \p ra.
  */
-static RD_UNUSED void rd_avg_add (rd_avg_t *ra, int64_t v) {
+static RD_UNUSED void rd_avg_add(rd_avg_t *ra, int64_t v) {
         mtx_lock(&ra->ra_lock);
         if (!ra->ra_enabled) {
                 mtx_unlock(&ra->ra_lock);
                 return;
         }
-	if (v > ra->ra_v.maxv)
-		ra->ra_v.maxv = v;
-	if (ra->ra_v.minv == 0 || v < ra->ra_v.minv)
-		ra->ra_v.minv = v;
-	ra->ra_v.sum += v;
-	ra->ra_v.cnt++;
+        if (v > ra->ra_v.maxv)
+                ra->ra_v.maxv = v;
+        if (ra->ra_v.minv == 0 || v < ra->ra_v.minv)
+                ra->ra_v.minv = v;
+        ra->ra_v.sum += v;
+        ra->ra_v.cnt++;
 #if WITH_HDRHISTOGRAM
         rd_hdr_histogram_record(ra->ra_hdr, v);
 #endif
@@ -96,7 +95,7 @@ static RD_UNUSED void rd_avg_add (rd_avg_t *ra, int64_t v) {
 /**
  * @brief Calculate the average
  */
-static RD_UNUSED void rd_avg_calc (rd_avg_t *ra, rd_ts_t now) {
+static RD_UNUSED void rd_avg_calc(rd_avg_t *ra, rd_ts_t now) {
         if (ra->ra_type == RD_AVG_GAUGE) {
                 if (ra->ra_v.cnt)
                         ra->ra_v.avg = ra->ra_v.sum / ra->ra_v.cnt;
@@ -121,8 +120,7 @@ static RD_UNUSED void rd_avg_calc (rd_avg_t *ra, rd_ts_t now) {
  *
  * @remark ra will be not locked by this function.
  */
-static RD_UNUSED int64_t
-rd_avg_quantile (const rd_avg_t *ra, double q) {
+static RD_UNUSED int64_t rd_avg_quantile(const rd_avg_t *ra, double q) {
 #if WITH_HDRHISTOGRAM
         return rd_hdr_histogram_quantile(ra->ra_hdr, q);
 #else
@@ -137,7 +135,7 @@ rd_avg_quantile (const rd_avg_t *ra, double q) {
  * Caller must free avg internal members by calling rd_avg_destroy()
  * on the \p dst.
  */
-static RD_UNUSED void rd_avg_rollover (rd_avg_t *dst, rd_avg_t *src) {
+static RD_UNUSED void rd_avg_rollover(rd_avg_t *dst, rd_avg_t *src) {
         rd_ts_t now;
 
         mtx_lock(&src->ra_lock);
@@ -150,26 +148,26 @@ static RD_UNUSED void rd_avg_rollover (rd_avg_t *dst, rd_avg_t *src) {
 
         mtx_init(&dst->ra_lock, mtx_plain);
         dst->ra_type = src->ra_type;
-	dst->ra_v    = src->ra_v;
+        dst->ra_v    = src->ra_v;
 #if WITH_HDRHISTOGRAM
         dst->ra_hdr = NULL;
 
-        dst->ra_hist.stddev = rd_hdr_histogram_stddev(src->ra_hdr);
-        dst->ra_hist.mean   = rd_hdr_histogram_mean(src->ra_hdr);
-        dst->ra_hist.oor    = src->ra_hdr->outOfRangeCount;
+        dst->ra_hist.stddev  = rd_hdr_histogram_stddev(src->ra_hdr);
+        dst->ra_hist.mean    = rd_hdr_histogram_mean(src->ra_hdr);
+        dst->ra_hist.oor     = src->ra_hdr->outOfRangeCount;
         dst->ra_hist.hdrsize = src->ra_hdr->allocatedSize;
-        dst->ra_hist.p50    = rd_hdr_histogram_quantile(src->ra_hdr, 50.0);
-        dst->ra_hist.p75    = rd_hdr_histogram_quantile(src->ra_hdr, 75.0);
-        dst->ra_hist.p90    = rd_hdr_histogram_quantile(src->ra_hdr, 90.0);
-        dst->ra_hist.p95    = rd_hdr_histogram_quantile(src->ra_hdr, 95.0);
-        dst->ra_hist.p99    = rd_hdr_histogram_quantile(src->ra_hdr, 99.0);
-        dst->ra_hist.p99_99 = rd_hdr_histogram_quantile(src->ra_hdr, 99.99);
+        dst->ra_hist.p50     = rd_hdr_histogram_quantile(src->ra_hdr, 50.0);
+        dst->ra_hist.p75     = rd_hdr_histogram_quantile(src->ra_hdr, 75.0);
+        dst->ra_hist.p90     = rd_hdr_histogram_quantile(src->ra_hdr, 90.0);
+        dst->ra_hist.p95     = rd_hdr_histogram_quantile(src->ra_hdr, 95.0);
+        dst->ra_hist.p99     = rd_hdr_histogram_quantile(src->ra_hdr, 99.0);
+        dst->ra_hist.p99_99  = rd_hdr_histogram_quantile(src->ra_hdr, 99.99);
 #else
         memset(&dst->ra_hist, 0, sizeof(dst->ra_hist));
 #endif
-	memset(&src->ra_v, 0, sizeof(src->ra_v));
+        memset(&src->ra_v, 0, sizeof(src->ra_v));
 
-        now = rd_clock();
+        now             = rd_clock();
         src->ra_v.start = now;
 
 #if WITH_HDRHISTOGRAM
@@ -181,23 +179,23 @@ static RD_UNUSED void rd_avg_rollover (rd_avg_t *dst, rd_avg_t *src) {
                 int64_t mindiff, maxdiff;
 
                 mindiff = src->ra_hdr->lowestTrackableValue -
-                        src->ra_hdr->lowestOutOfRange;
+                          src->ra_hdr->lowestOutOfRange;
 
                 if (mindiff > 0) {
                         /* There were low out of range values, grow lower
                          * span to fit lowest out of range value + 20%. */
                         vmin = src->ra_hdr->lowestOutOfRange +
-                                (int64_t)((double)mindiff * 0.2);
+                               (int64_t)((double)mindiff * 0.2);
                 }
 
                 maxdiff = src->ra_hdr->highestOutOfRange -
-                        src->ra_hdr->highestTrackableValue;
+                          src->ra_hdr->highestTrackableValue;
 
                 if (maxdiff > 0) {
                         /* There were high out of range values, grow higher
                          * span to fit highest out of range value + 20%. */
                         vmax = src->ra_hdr->highestOutOfRange +
-                                (int64_t)((double)maxdiff * 0.2);
+                               (int64_t)((double)maxdiff * 0.2);
                 }
 
                 if (vmin == src->ra_hdr->lowestTrackableValue &&
@@ -226,15 +224,18 @@ static RD_UNUSED void rd_avg_rollover (rd_avg_t *dst, rd_avg_t *src) {
 /**
  * Initialize an averager
  */
-static RD_UNUSED void rd_avg_init (rd_avg_t *ra, int type,
-                                   int64_t exp_min, int64_t exp_max,
-                                   int sigfigs, int enable) {
+static RD_UNUSED void rd_avg_init(rd_avg_t *ra,
+                                  int type,
+                                  int64_t exp_min,
+                                  int64_t exp_max,
+                                  int sigfigs,
+                                  int enable) {
         memset(ra, 0, sizeof(*ra));
         mtx_init(&ra->ra_lock, 0);
         ra->ra_enabled = enable;
         if (!enable)
                 return;
-        ra->ra_type = type;
+        ra->ra_type    = type;
         ra->ra_v.start = rd_clock();
 #if WITH_HDRHISTOGRAM
         /* Start off the histogram with expected min,max span,
@@ -247,7 +248,7 @@ static RD_UNUSED void rd_avg_init (rd_avg_t *ra, int type,
 /**
  * Destroy averager
  */
-static RD_UNUSED void rd_avg_destroy (rd_avg_t *ra) {
+static RD_UNUSED void rd_avg_destroy(rd_avg_t *ra) {
 #if WITH_HDRHISTOGRAM
         if (ra->ra_hdr)
                 rd_hdr_histogram_destroy(ra->ra_hdr);
