@@ -539,7 +539,8 @@ int rd_kafka_q_serve(rd_kafka_q_t *rkq,
  *
  * @locality Any thread.
  */
-static size_t rd_kafka_purge_outdated_messages(int32_t version,
+static size_t rd_kafka_purge_outdated_messages(rd_kafka_toppar_t *rktp,
+                                               int32_t version,
                                                rd_kafka_message_t **rkmessages,
                                                size_t cnt) {
         size_t valid_count = 0;
@@ -548,7 +549,8 @@ static size_t rd_kafka_purge_outdated_messages(int32_t version,
         for (i = 0; i < cnt; i++) {
                 rd_kafka_op_t *rko;
                 rko = rkmessages[i]->_private;
-                if (rd_kafka_op_version_outdated(rko, version)) {
+                if (rko->rko_rktp == rktp &&
+                    rd_kafka_op_version_outdated(rko, version)) {
                         /* This also destroys the corresponding rkmessage. */
                         rd_kafka_op_destroy(rko);
                 } else if (i > valid_count) {
@@ -620,16 +622,16 @@ int rd_kafka_q_serve_rkmessages(rd_kafka_q_t *rkq,
 
                 mtx_unlock(&rkq->rkq_lock);
 
-                if (rd_kafka_op_version_outdated(rko, 0)) {
-                        /* Outdated op, put on discard queue */
-                        TAILQ_INSERT_TAIL(&tmpq, rko, rko_link);
+                if (unlikely(rko->rko_type == RD_KAFKA_OP_BARRIER)) {
+                        cnt = (unsigned int)rd_kafka_purge_outdated_messages(
+                            rko->rko_rktp, rko->rko_version, rkmessages, cnt);
+                        rd_kafka_op_destroy(rko);
                         continue;
                 }
 
-                if (unlikely(rko->rko_type == RD_KAFKA_OP_BARRIER)) {
-                        cnt = (unsigned int)rd_kafka_purge_outdated_messages(
-                            rko->rko_version, rkmessages, cnt);
-                        rd_kafka_op_destroy(rko);
+                if (rd_kafka_op_version_outdated(rko, 0)) {
+                        /* Outdated op, put on discard queue */
+                        TAILQ_INSERT_TAIL(&tmpq, rko, rko_link);
                         continue;
                 }
 
