@@ -34,7 +34,7 @@
 #include "rdstring.h"
 
 #if defined(__FreeBSD__) || defined(__OpenBSD__)
-#include <sys/wait.h>  /* For WIF.. */
+#include <sys/wait.h> /* For WIF.. */
 #endif
 
 #ifdef __APPLE__
@@ -74,9 +74,11 @@ typedef struct rd_kafka_sasl_cyrus_state_s {
 /**
  * Handle received frame from broker.
  */
-static int rd_kafka_sasl_cyrus_recv (struct rd_kafka_transport_s *rktrans,
-                                     const void *buf, size_t size,
-                                     char *errstr, size_t errstr_size) {
+static int rd_kafka_sasl_cyrus_recv(struct rd_kafka_transport_s *rktrans,
+                                    const void *buf,
+                                    size_t size,
+                                    char *errstr,
+                                    size_t errstr_size) {
         rd_kafka_sasl_cyrus_state_t *state = rktrans->rktrans_sasl.state;
         int r;
         int sendcnt = 0;
@@ -89,15 +91,15 @@ static int rd_kafka_sasl_cyrus_recv (struct rd_kafka_transport_s *rktrans,
                 const char *out;
                 unsigned int outlen;
 
-                r = sasl_client_step(state->conn,
-                                     size > 0 ? buf : NULL, size,
-                                     &interact,
-                                     &out, &outlen);
+                mtx_lock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
+                r = sasl_client_step(state->conn, size > 0 ? buf : NULL, size,
+                                     &interact, &out, &outlen);
+                mtx_unlock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
 
                 if (r >= 0) {
                         /* Note: outlen may be 0 here for an empty response */
-                        if (rd_kafka_sasl_send(rktrans, out, outlen,
-                                               errstr, errstr_size) == -1)
+                        if (rd_kafka_sasl_send(rktrans, out, outlen, errstr,
+                                               errstr_size) == -1)
                                 return -1;
                         sendcnt++;
                 }
@@ -105,16 +107,14 @@ static int rd_kafka_sasl_cyrus_recv (struct rd_kafka_transport_s *rktrans,
                 if (r == SASL_INTERACT)
                         rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "SASL",
                                    "SASL_INTERACT: %lu %s, %s, %s, %p",
-                                   interact->id,
-                                   interact->challenge,
-                                   interact->prompt,
-                                   interact->defresult,
+                                   interact->id, interact->challenge,
+                                   interact->prompt, interact->defresult,
                                    interact->result);
 
         } while (r == SASL_INTERACT);
 
         if (r == SASL_CONTINUE)
-                return 0;  /* Wait for more data from broker */
+                return 0; /* Wait for more data from broker */
         else if (r != SASL_OK) {
                 rd_snprintf(errstr, errstr_size,
                             "SASL handshake failed (step): %s",
@@ -138,8 +138,8 @@ static int rd_kafka_sasl_cyrus_recv (struct rd_kafka_transport_s *rktrans,
                         rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "SASL",
                                    "%s authentication complete but awaiting "
                                    "final response from broker",
-                                   rktrans->rktrans_rkb->rkb_rk->rk_conf.
-                                   sasl.mechanisms);
+                                   rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl
+                                       .mechanisms);
                         return 0;
                 }
         }
@@ -150,9 +150,11 @@ auth_successful:
             RD_KAFKA_DBG_SECURITY) {
                 const char *user, *mech, *authsrc;
 
+                mtx_lock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
                 if (sasl_getprop(state->conn, SASL_USERNAME,
                                  (const void **)&user) != SASL_OK)
                         user = "(unknown)";
+                mtx_unlock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
 
                 if (sasl_getprop(state->conn, SASL_MECHNAME,
                                  (const void **)&mech) != SASL_OK)
@@ -163,8 +165,8 @@ auth_successful:
                         authsrc = "(unknown)";
 
                 rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "SASL",
-                           "Authenticated as %s using %s (%s)",
-                           user, mech, authsrc);
+                           "Authenticated as %s using %s (%s)", user, mech,
+                           authsrc);
         }
 
         rd_kafka_sasl_auth_done(rktrans);
@@ -174,9 +176,8 @@ auth_successful:
 
 
 
-
-static ssize_t render_callback (const char *key, char *buf,
-                                size_t size, void *opaque) {
+static ssize_t
+render_callback(const char *key, char *buf, size_t size, void *opaque) {
         rd_kafka_t *rk = opaque;
         rd_kafka_conf_res_t res;
         size_t destsize = size;
@@ -187,7 +188,7 @@ static ssize_t render_callback (const char *key, char *buf,
                 return -1;
 
         /* Dont include \0 in returned size */
-        return (destsize > 0 ? destsize-1 : destsize);
+        return (destsize > 0 ? destsize - 1 : destsize);
 }
 
 
@@ -198,7 +199,7 @@ static ssize_t render_callback (const char *key, char *buf,
  *
  * @locality rdkafka main thread
  */
-static int rd_kafka_sasl_cyrus_kinit_refresh (rd_kafka_t *rk) {
+static int rd_kafka_sasl_cyrus_kinit_refresh(rd_kafka_t *rk) {
         rd_kafka_sasl_cyrus_handle_t *handle = rk->rk_sasl.handle;
         int r;
         char *cmd;
@@ -207,9 +208,8 @@ static int rd_kafka_sasl_cyrus_kinit_refresh (rd_kafka_t *rk) {
         int duration;
 
         /* Build kinit refresh command line using string rendering and config */
-        cmd = rd_string_render(rk->rk_conf.sasl.kinit_cmd,
-                               errstr, sizeof(errstr),
-                               render_callback, rk);
+        cmd = rd_string_render(rk->rk_conf.sasl.kinit_cmd, errstr,
+                               sizeof(errstr), render_callback, rk);
         if (!cmd) {
                 rd_kafka_log(rk, LOG_ERR, "SASLREFRESH",
                              "Failed to construct kinit command "
@@ -233,8 +233,8 @@ static int rd_kafka_sasl_cyrus_kinit_refresh (rd_kafka_t *rk) {
         duration = (int)((rd_clock() - ts_start) / 1000);
         if (duration > 5000)
                 rd_kafka_log(rk, LOG_WARNING, "SASLREFRESH",
-                             "Slow Kerberos ticket refresh: %dms: %s",
-                             duration, cmd);
+                             "Slow Kerberos ticket refresh: %dms: %s", duration,
+                             cmd);
 
         /* Regardless of outcome from the kinit command (it can fail
          * even if the ticket is available), we now allow broker connections. */
@@ -242,7 +242,8 @@ static int rd_kafka_sasl_cyrus_kinit_refresh (rd_kafka_t *rk) {
                 rd_kafka_dbg(rk, SECURITY, "SASLREFRESH",
                              "First kinit command finished: waking up "
                              "broker threads");
-                rd_kafka_all_brokers_wakeup(rk, RD_KAFKA_BROKER_STATE_INIT);
+                rd_kafka_all_brokers_wakeup(rk, RD_KAFKA_BROKER_STATE_INIT,
+                                            "Kerberos ticket refresh");
         }
 
         if (r == -1) {
@@ -288,8 +289,8 @@ static int rd_kafka_sasl_cyrus_kinit_refresh (rd_kafka_t *rk) {
  *
  * @locality rdkafka main thread
  */
-static void rd_kafka_sasl_cyrus_kinit_refresh_tmr_cb (rd_kafka_timers_t *rkts,
-                                                      void *arg) {
+static void rd_kafka_sasl_cyrus_kinit_refresh_tmr_cb(rd_kafka_timers_t *rkts,
+                                                     void *arg) {
         rd_kafka_t *rk = arg;
 
         rd_kafka_sasl_cyrus_kinit_refresh(rk);
@@ -302,10 +303,11 @@ static void rd_kafka_sasl_cyrus_kinit_refresh_tmr_cb (rd_kafka_timers_t *rkts,
  * libsasl callbacks
  *
  */
-static RD_UNUSED int
-rd_kafka_sasl_cyrus_cb_getopt (void *context, const char *plugin_name,
-                         const char *option,
-                         const char **result, unsigned *len) {
+static RD_UNUSED int rd_kafka_sasl_cyrus_cb_getopt(void *context,
+                                                   const char *plugin_name,
+                                                   const char *option,
+                                                   const char **result,
+                                                   unsigned *len) {
         rd_kafka_transport_t *rktrans = context;
 
         if (!strcmp(option, "client_mech_list"))
@@ -317,14 +319,14 @@ rd_kafka_sasl_cyrus_cb_getopt (void *context, const char *plugin_name,
                 *len = strlen(*result);
 
         rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "LIBSASL",
-                   "CB_GETOPT: plugin %s, option %s: returning %s",
-                   plugin_name, option, *result);
+                   "CB_GETOPT: plugin %s, option %s: returning %s", plugin_name,
+                   option, *result);
 
         return SASL_OK;
 }
 
-static int rd_kafka_sasl_cyrus_cb_log (void *context, int level,
-                                       const char *message) {
+static int
+rd_kafka_sasl_cyrus_cb_log(void *context, int level, const char *message) {
         rd_kafka_transport_t *rktrans = context;
 
         /* Provide a more helpful error message in case Kerberos
@@ -333,31 +335,37 @@ static int rd_kafka_sasl_cyrus_cb_log (void *context, int level,
             strstr(rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.mechanisms,
                    "GSSAPI"))
                 message =
-                        "Cyrus/libsasl2 is missing a GSSAPI module: "
-                        "make sure the libsasl2-modules-gssapi-mit or "
-                        "cyrus-sasl-gssapi packages are installed";
+                    "Cyrus/libsasl2 is missing a GSSAPI module: "
+                    "make sure the libsasl2-modules-gssapi-mit or "
+                    "cyrus-sasl-gssapi packages are installed";
 
         /* Treat the "client step" log messages as debug. */
-        if (level >= LOG_DEBUG ||
-            !strncmp(message, "GSSAPI client step ", 19))
-                rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "LIBSASL",
-                           "%s", message);
+        if (level >= LOG_DEBUG || !strncmp(message, "GSSAPI client step ", 19))
+                rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "LIBSASL", "%s",
+                           message);
         else
-                rd_rkb_log(rktrans->rktrans_rkb, level, "LIBSASL",
-                           "%s", message);
+                rd_rkb_log(rktrans->rktrans_rkb, level, "LIBSASL", "%s",
+                           message);
 
         return SASL_OK;
 }
 
 
-static int rd_kafka_sasl_cyrus_cb_getsimple (void *context, int id,
-                                       const char **result, unsigned *len) {
+static int rd_kafka_sasl_cyrus_cb_getsimple(void *context,
+                                            int id,
+                                            const char **result,
+                                            unsigned *len) {
         rd_kafka_transport_t *rktrans = context;
 
-        switch (id)
-        {
+        switch (id) {
         case SASL_CB_USER:
         case SASL_CB_AUTHNAME:
+                /* Since cyrus expects the returned pointer to be stable
+                 * and not have its content changed, but the username
+                 * and password may be updated at anytime by the application
+                 * calling sasl_set_credentials(), we need to lock
+                 * rk_conf.sasl.lock before each call into cyrus-sasl.
+                 * So when we get here the lock is already held. */
                 *result = rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.username;
                 break;
 
@@ -376,11 +384,14 @@ static int rd_kafka_sasl_cyrus_cb_getsimple (void *context, int id,
 }
 
 
-static int rd_kafka_sasl_cyrus_cb_getsecret (sasl_conn_t *conn, void *context,
-                                       int id, sasl_secret_t **psecret) {
+static int rd_kafka_sasl_cyrus_cb_getsecret(sasl_conn_t *conn,
+                                            void *context,
+                                            int id,
+                                            sasl_secret_t **psecret) {
         rd_kafka_transport_t *rktrans = context;
         const char *password;
 
+        /* rk_conf.sasl.lock is already locked */
         password = rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.password;
 
         if (!password) {
@@ -393,21 +404,23 @@ static int rd_kafka_sasl_cyrus_cb_getsecret (sasl_conn_t *conn, void *context,
         }
 
         rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "LIBSASL",
-                   "CB_GETSECRET: id 0x%x: returning %s",
-                   id, *psecret ? "(hidden)":"NULL");
+                   "CB_GETSECRET: id 0x%x: returning %s", id,
+                   *psecret ? "(hidden)" : "NULL");
 
         return SASL_OK;
 }
 
-static int rd_kafka_sasl_cyrus_cb_chalprompt (void *context, int id,
-                                        const char *challenge,
-                                        const char *prompt,
-                                        const char *defres,
-                                        const char **result, unsigned *len) {
+static int rd_kafka_sasl_cyrus_cb_chalprompt(void *context,
+                                             int id,
+                                             const char *challenge,
+                                             const char *prompt,
+                                             const char *defres,
+                                             const char **result,
+                                             unsigned *len) {
         rd_kafka_transport_t *rktrans = context;
 
         *result = "min_chalprompt";
-        *len = strlen(*result);
+        *len    = strlen(*result);
 
         rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "LIBSASL",
                    "CB_CHALPROMPT: id 0x%x, challenge %s, prompt %s, "
@@ -417,9 +430,10 @@ static int rd_kafka_sasl_cyrus_cb_chalprompt (void *context, int id,
         return SASL_OK;
 }
 
-static int rd_kafka_sasl_cyrus_cb_getrealm (void *context, int id,
-                                      const char **availrealms,
-                                      const char **result) {
+static int rd_kafka_sasl_cyrus_cb_getrealm(void *context,
+                                           int id,
+                                           const char **availrealms,
+                                           const char **result) {
         rd_kafka_transport_t *rktrans = context;
 
         *result = *availrealms;
@@ -431,43 +445,49 @@ static int rd_kafka_sasl_cyrus_cb_getrealm (void *context, int id,
 }
 
 
-static RD_UNUSED int
-rd_kafka_sasl_cyrus_cb_canon (sasl_conn_t *conn,
-                              void *context,
-                              const char *in, unsigned inlen,
-                              unsigned flags,
-                              const char *user_realm,
-                              char *out, unsigned out_max,
-                              unsigned *out_len) {
+static RD_UNUSED int rd_kafka_sasl_cyrus_cb_canon(sasl_conn_t *conn,
+                                                  void *context,
+                                                  const char *in,
+                                                  unsigned inlen,
+                                                  unsigned flags,
+                                                  const char *user_realm,
+                                                  char *out,
+                                                  unsigned out_max,
+                                                  unsigned *out_len) {
         rd_kafka_transport_t *rktrans = context;
 
-        if (strstr(rktrans->rktrans_rkb->rkb_rk->rk_conf.
-                   sasl.mechanisms, "GSSAPI")) {
-                *out_len = rd_snprintf(out, out_max, "%s",
-                                       rktrans->rktrans_rkb->rkb_rk->
-                                       rk_conf.sasl.principal);
-        } else if (!strcmp(rktrans->rktrans_rkb->rkb_rk->rk_conf.
-                           sasl.mechanisms, "PLAIN")) {
+        if (strstr(rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.mechanisms,
+                   "GSSAPI")) {
+                *out_len = rd_snprintf(
+                    out, out_max, "%s",
+                    rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.principal);
+        } else if (!strcmp(
+                       rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.mechanisms,
+                       "PLAIN")) {
                 *out_len = rd_snprintf(out, out_max, "%.*s", inlen, in);
         } else
                 out = NULL;
 
-        rd_rkb_dbg(rktrans->rktrans_rkb, SECURITY, "LIBSASL",
-                   "CB_CANON: flags 0x%x, \"%.*s\" @ \"%s\": returning \"%.*s\"",
-                   flags, (int)inlen, in, user_realm, (int)(*out_len), out);
+        rd_rkb_dbg(
+            rktrans->rktrans_rkb, SECURITY, "LIBSASL",
+            "CB_CANON: flags 0x%x, \"%.*s\" @ \"%s\": returning \"%.*s\"",
+            flags, (int)inlen, in, user_realm, (int)(*out_len), out);
 
         return out ? SASL_OK : SASL_FAIL;
 }
 
 
-static void rd_kafka_sasl_cyrus_close (struct rd_kafka_transport_s *rktrans) {
+static void rd_kafka_sasl_cyrus_close(struct rd_kafka_transport_s *rktrans) {
         rd_kafka_sasl_cyrus_state_t *state = rktrans->rktrans_sasl.state;
 
         if (!state)
                 return;
 
-        if (state->conn)
+        if (state->conn) {
+                mtx_lock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
                 sasl_dispose(&state->conn);
+                mtx_unlock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
+        }
         rd_free(state);
 }
 
@@ -479,37 +499,42 @@ static void rd_kafka_sasl_cyrus_close (struct rd_kafka_transport_s *rktrans) {
  *
  * Locality: broker thread
  */
-static int rd_kafka_sasl_cyrus_client_new (rd_kafka_transport_t *rktrans,
-                                           const char *hostname,
-                                           char *errstr, size_t errstr_size) {
+static int rd_kafka_sasl_cyrus_client_new(rd_kafka_transport_t *rktrans,
+                                          const char *hostname,
+                                          char *errstr,
+                                          size_t errstr_size) {
         int r;
         rd_kafka_sasl_cyrus_state_t *state;
-        rd_kafka_broker_t *rkb = rktrans->rktrans_rkb;
-        rd_kafka_t *rk = rkb->rkb_rk;
+        rd_kafka_broker_t *rkb        = rktrans->rktrans_rkb;
+        rd_kafka_t *rk                = rkb->rkb_rk;
         sasl_callback_t callbacks[16] = {
-                // { SASL_CB_GETOPT, (void *)rd_kafka_sasl_cyrus_cb_getopt, rktrans },
-                { SASL_CB_LOG, (void *)rd_kafka_sasl_cyrus_cb_log, rktrans },
-                { SASL_CB_AUTHNAME, (void *)rd_kafka_sasl_cyrus_cb_getsimple, rktrans },
-                { SASL_CB_PASS, (void *)rd_kafka_sasl_cyrus_cb_getsecret, rktrans },
-                { SASL_CB_ECHOPROMPT, (void *)rd_kafka_sasl_cyrus_cb_chalprompt, rktrans },
-                { SASL_CB_GETREALM, (void *)rd_kafka_sasl_cyrus_cb_getrealm, rktrans },
-                { SASL_CB_CANON_USER, (void *)rd_kafka_sasl_cyrus_cb_canon, rktrans },
-                { SASL_CB_LIST_END }
-        };
+            // { SASL_CB_GETOPT, (void *)rd_kafka_sasl_cyrus_cb_getopt, rktrans
+            // },
+            {SASL_CB_LOG, (void *)rd_kafka_sasl_cyrus_cb_log, rktrans},
+            {SASL_CB_AUTHNAME, (void *)rd_kafka_sasl_cyrus_cb_getsimple,
+             rktrans},
+            {SASL_CB_PASS, (void *)rd_kafka_sasl_cyrus_cb_getsecret, rktrans},
+            {SASL_CB_ECHOPROMPT, (void *)rd_kafka_sasl_cyrus_cb_chalprompt,
+             rktrans},
+            {SASL_CB_GETREALM, (void *)rd_kafka_sasl_cyrus_cb_getrealm,
+             rktrans},
+            {SASL_CB_CANON_USER, (void *)rd_kafka_sasl_cyrus_cb_canon, rktrans},
+            {SASL_CB_LIST_END}};
 
-        state = rd_calloc(1, sizeof(*state));
+        state                       = rd_calloc(1, sizeof(*state));
         rktrans->rktrans_sasl.state = state;
 
         /* SASL_CB_USER is needed for PLAIN but breaks GSSAPI */
         if (!strcmp(rk->rk_conf.sasl.mechanisms, "PLAIN")) {
                 int endidx;
                 /* Find end of callbacks array */
-                for (endidx = 0 ;
-                     callbacks[endidx].id != SASL_CB_LIST_END ; endidx++)
+                for (endidx = 0; callbacks[endidx].id != SASL_CB_LIST_END;
+                     endidx++)
                         ;
 
                 callbacks[endidx].id = SASL_CB_USER;
-                callbacks[endidx].proc = (void *)rd_kafka_sasl_cyrus_cb_getsimple;
+                callbacks[endidx].proc =
+                    (void *)rd_kafka_sasl_cyrus_cb_getsimple;
                 callbacks[endidx].context = rktrans;
                 endidx++;
                 callbacks[endidx].id = SASL_CB_LIST_END;
@@ -517,9 +542,11 @@ static int rd_kafka_sasl_cyrus_client_new (rd_kafka_transport_t *rktrans,
 
         memcpy(state->callbacks, callbacks, sizeof(callbacks));
 
-        r = sasl_client_new(rk->rk_conf.sasl.service_name, hostname,
-                            NULL, NULL, /* no local & remote IP checks */
+        mtx_lock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
+        r = sasl_client_new(rk->rk_conf.sasl.service_name, hostname, NULL,
+                            NULL, /* no local & remote IP checks */
                             state->callbacks, 0, &state->conn);
+        mtx_unlock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
         if (r != SASL_OK) {
                 rd_snprintf(errstr, errstr_size, "%s",
                             sasl_errstring(r, NULL, NULL));
@@ -528,8 +555,8 @@ static int rd_kafka_sasl_cyrus_client_new (rd_kafka_transport_t *rktrans,
 
         if (rk->rk_conf.debug & RD_KAFKA_DBG_SECURITY) {
                 const char *avail_mechs;
-                sasl_listmech(state->conn, NULL, NULL, " ", NULL,
-                              &avail_mechs, NULL, NULL);
+                sasl_listmech(state->conn, NULL, NULL, " ", NULL, &avail_mechs,
+                              NULL, NULL);
                 rd_rkb_dbg(rkb, SECURITY, "SASL",
                            "My supported SASL mechanisms: %s", avail_mechs);
         }
@@ -539,27 +566,28 @@ static int rd_kafka_sasl_cyrus_client_new (rd_kafka_transport_t *rktrans,
                 unsigned int outlen;
                 const char *mech = NULL;
 
-                r = sasl_client_start(state->conn,
-                                      rk->rk_conf.sasl.mechanisms,
+                mtx_lock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
+                r = sasl_client_start(state->conn, rk->rk_conf.sasl.mechanisms,
                                       NULL, &out, &outlen, &mech);
+                mtx_unlock(&rktrans->rktrans_rkb->rkb_rk->rk_conf.sasl.lock);
 
                 if (r >= 0)
-                        if (rd_kafka_sasl_send(rktrans, out, outlen,
-                                               errstr, errstr_size))
+                        if (rd_kafka_sasl_send(rktrans, out, outlen, errstr,
+                                               errstr_size))
                                 return -1;
         } while (r == SASL_INTERACT);
 
         if (r == SASL_OK) {
-                /* PLAIN is appearantly done here, but we still need to make sure
-                 * the PLAIN frame is sent and we get a response back (but we must
-                 * not pass the response to libsasl or it will fail). */
+                /* PLAIN is appearantly done here, but we still need to make
+                 * sure the PLAIN frame is sent and we get a response back (but
+                 * we must not pass the response to libsasl or it will fail). */
                 rktrans->rktrans_sasl.complete = 1;
                 return 0;
 
         } else if (r != SASL_CONTINUE) {
                 rd_snprintf(errstr, errstr_size,
-                            "SASL handshake failed (start (%d)): %s",
-                            r, sasl_errdetail(state->conn));
+                            "SASL handshake failed (start (%d)): %s", r,
+                            sasl_errdetail(state->conn));
                 return -1;
         }
 
@@ -571,7 +599,7 @@ static int rd_kafka_sasl_cyrus_client_new (rd_kafka_transport_t *rktrans,
  * @brief SASL/GSSAPI is ready when at least one kinit command has been
  *        executed (regardless of exit status).
  */
-static rd_bool_t rd_kafka_sasl_cyrus_ready (rd_kafka_t *rk) {
+static rd_bool_t rd_kafka_sasl_cyrus_ready(rd_kafka_t *rk) {
         rd_kafka_sasl_cyrus_handle_t *handle = rk->rk_sasl.handle;
         if (!rk->rk_conf.sasl.relogin_min_time)
                 return rd_true;
@@ -584,16 +612,15 @@ static rd_bool_t rd_kafka_sasl_cyrus_ready (rd_kafka_t *rk) {
 /**
  * @brief Per-client-instance initializer
  */
-static int rd_kafka_sasl_cyrus_init (rd_kafka_t *rk,
-                                     char *errstr, size_t errstr_size) {
+static int
+rd_kafka_sasl_cyrus_init(rd_kafka_t *rk, char *errstr, size_t errstr_size) {
         rd_kafka_sasl_cyrus_handle_t *handle;
 
-        if (!rk->rk_conf.sasl.relogin_min_time ||
-            !rk->rk_conf.sasl.kinit_cmd ||
+        if (!rk->rk_conf.sasl.relogin_min_time || !rk->rk_conf.sasl.kinit_cmd ||
             strcmp(rk->rk_conf.sasl.mechanisms, "GSSAPI"))
                 return 0; /* kinit not configured, no need to start timer */
 
-        handle = rd_calloc(1, sizeof(*handle));
+        handle             = rd_calloc(1, sizeof(*handle));
         rk->rk_sasl.handle = handle;
 
         rd_kafka_timer_start(&rk->rk_timers, &handle->kinit_refresh_tmr,
@@ -603,7 +630,7 @@ static int rd_kafka_sasl_cyrus_init (rd_kafka_t *rk,
         /* Kick off the timer immediately to refresh the ticket.
          * (Timer is triggered from the main loop). */
         rd_kafka_timer_override_once(&rk->rk_timers, &handle->kinit_refresh_tmr,
-                                     0/*immediately*/);
+                                     0 /*immediately*/);
 
         return 0;
 }
@@ -612,7 +639,7 @@ static int rd_kafka_sasl_cyrus_init (rd_kafka_t *rk,
 /**
  * @brief Per-client-instance destructor
  */
-static void rd_kafka_sasl_cyrus_term (rd_kafka_t *rk) {
+static void rd_kafka_sasl_cyrus_term(rd_kafka_t *rk) {
         rd_kafka_sasl_cyrus_handle_t *handle = rk->rk_sasl.handle;
 
         if (!handle)
@@ -624,20 +651,19 @@ static void rd_kafka_sasl_cyrus_term (rd_kafka_t *rk) {
 }
 
 
-static int rd_kafka_sasl_cyrus_conf_validate (rd_kafka_t *rk,
-                                       char *errstr, size_t errstr_size) {
+static int rd_kafka_sasl_cyrus_conf_validate(rd_kafka_t *rk,
+                                             char *errstr,
+                                             size_t errstr_size) {
 
         if (strcmp(rk->rk_conf.sasl.mechanisms, "GSSAPI"))
                 return 0;
 
-        if (rk->rk_conf.sasl.relogin_min_time &&
-            rk->rk_conf.sasl.kinit_cmd) {
+        if (rk->rk_conf.sasl.relogin_min_time && rk->rk_conf.sasl.kinit_cmd) {
                 char *cmd;
                 char tmperr[128];
 
-                cmd = rd_string_render(rk->rk_conf.sasl.kinit_cmd,
-                                       tmperr, sizeof(tmperr),
-                                       render_callback, rk);
+                cmd = rd_string_render(rk->rk_conf.sasl.kinit_cmd, tmperr,
+                                       sizeof(tmperr), render_callback, rk);
 
                 if (!cmd) {
                         rd_snprintf(errstr, errstr_size,
@@ -656,8 +682,9 @@ static int rd_kafka_sasl_cyrus_conf_validate (rd_kafka_t *rk,
 /**
  * Global SASL termination.
  */
-void rd_kafka_sasl_cyrus_global_term (void) {
-        /* NOTE: Should not be called since the application may be using SASL too*/
+void rd_kafka_sasl_cyrus_global_term(void) {
+        /* NOTE: Should not be called since the application may be using SASL
+         * too*/
         /* sasl_done(); */
         mtx_destroy(&rd_kafka_sasl_cyrus_kinit_lock);
 }
@@ -666,7 +693,7 @@ void rd_kafka_sasl_cyrus_global_term (void) {
 /**
  * Global SASL init, called once per runtime.
  */
-int rd_kafka_sasl_cyrus_global_init (void) {
+int rd_kafka_sasl_cyrus_global_init(void) {
         int r;
 
         mtx_init(&rd_kafka_sasl_cyrus_kinit_lock, mtx_plain);
@@ -683,12 +710,11 @@ int rd_kafka_sasl_cyrus_global_init (void) {
 
 
 const struct rd_kafka_sasl_provider rd_kafka_sasl_cyrus_provider = {
-        .name          = "Cyrus",
-        .init          = rd_kafka_sasl_cyrus_init,
-        .term          = rd_kafka_sasl_cyrus_term,
-        .client_new    = rd_kafka_sasl_cyrus_client_new,
-        .recv          = rd_kafka_sasl_cyrus_recv,
-        .close         = rd_kafka_sasl_cyrus_close,
-        .ready         = rd_kafka_sasl_cyrus_ready,
-        .conf_validate = rd_kafka_sasl_cyrus_conf_validate
-};
+    .name          = "Cyrus",
+    .init          = rd_kafka_sasl_cyrus_init,
+    .term          = rd_kafka_sasl_cyrus_term,
+    .client_new    = rd_kafka_sasl_cyrus_client_new,
+    .recv          = rd_kafka_sasl_cyrus_recv,
+    .close         = rd_kafka_sasl_cyrus_close,
+    .ready         = rd_kafka_sasl_cyrus_ready,
+    .conf_validate = rd_kafka_sasl_cyrus_conf_validate};
