@@ -37,23 +37,26 @@
  */
 
 typedef struct rd_list_s {
-        int    rl_size;
-        int    rl_cnt;
+        int rl_size;
+        int rl_cnt;
         void **rl_elems;
-	void (*rl_free_cb) (void *);
-	int    rl_flags;
-#define RD_LIST_F_ALLOCATED  0x1  /* The rd_list_t is allocated,
-				   * will be free on destroy() */
-#define RD_LIST_F_SORTED     0x2  /* Set by sort(), cleared by any mutations.
-				   * When this flag is set bsearch() is used
-				   * by find(), otherwise a linear search. */
-#define RD_LIST_F_FIXED_SIZE 0x4  /* Assert on grow, when prealloc()ed */
-#define RD_LIST_F_UNIQUE     0x8  /* Don't allow duplicates:
-                                   * ONLY ENFORCED BY CALLER. */
-        int     rl_elemsize;      /**< Element size (when prealloc()ed) */
-        void   *rl_p;             /**< Start of prealloced elements,
-                                   *   the allocation itself starts at rl_elems
-                                   */
+        void (*rl_free_cb)(void *);
+        int rl_flags;
+#define RD_LIST_F_ALLOCATED                                                    \
+        0x1 /* The rd_list_t is allocated,                                     \
+             * will be free on destroy() */
+#define RD_LIST_F_SORTED                                                       \
+        0x2                      /* Set by sort(), cleared by any mutations.   \
+                                  * When this flag is set bsearch() is used    \
+                                  * by find(), otherwise a linear search. */
+#define RD_LIST_F_FIXED_SIZE 0x4 /* Assert on grow, when prealloc()ed */
+#define RD_LIST_F_UNIQUE                                                       \
+        0x8              /* Don't allow duplicates:                            \
+                          * ONLY ENFORCED BY CALLER. */
+        int rl_elemsize; /**< Element size (when prealloc()ed) */
+        void *rl_p;      /**< Start of prealloced elements,
+                          *   the allocation itself starts at rl_elems
+                          */
 } rd_list_t;
 
 
@@ -65,14 +68,14 @@ typedef struct rd_list_s {
  * @returns \p rl
  */
 rd_list_t *
-rd_list_init (rd_list_t *rl, int initial_size, void (*free_cb) (void *));
+rd_list_init(rd_list_t *rl, int initial_size, void (*free_cb)(void *));
 
 
 /**
  * @brief Same as rd_list_init() but uses initial_size and free_cb
  *        from the provided \p src list.
  */
-rd_list_t *rd_list_init_copy (rd_list_t *rl, const rd_list_t *src);
+rd_list_t *rd_list_init_copy(rd_list_t *rl, const rd_list_t *src);
 
 /**
  * @brief Allocate a new list pointer and initialize
@@ -82,14 +85,14 @@ rd_list_t *rd_list_init_copy (rd_list_t *rl, const rd_list_t *src);
  *
  * Use rd_list_destroy() to free.
  */
-rd_list_t *rd_list_new (int initial_size, void (*free_cb) (void *));
+rd_list_t *rd_list_new(int initial_size, void (*free_cb)(void *));
 
 
 /**
  * @brief Prepare list to for an additional \p size elements.
  *        This is an optimization to avoid incremental grows.
  */
-void rd_list_grow (rd_list_t *rl, size_t size);
+void rd_list_grow(rd_list_t *rl, size_t size);
 
 /**
  * @brief Preallocate elements to avoid having to pass an allocated pointer to
@@ -102,15 +105,17 @@ void rd_list_grow (rd_list_t *rl, size_t size);
  *
  * @remark Preallocated element lists can't grow past \p size.
  */
-void rd_list_prealloc_elems (rd_list_t *rl, size_t elemsize, size_t size,
-                             int memzero);
+void rd_list_prealloc_elems(rd_list_t *rl,
+                            size_t elemsize,
+                            size_t size,
+                            int memzero);
 
 /**
  * @brief Set the number of valid elements, this must only be used
  *        with prealloc_elems() to make the preallocated elements directly
  *        usable.
  */
-void rd_list_set_cnt (rd_list_t *rl, size_t cnt);
+void rd_list_set_cnt(rd_list_t *rl, size_t cnt);
 
 
 /**
@@ -120,7 +125,7 @@ void rd_list_set_cnt (rd_list_t *rl, size_t cnt);
  *
  * Typical use is rd_list_free_cb(rd_list_remove_cmp(....));
  */
-void rd_list_free_cb (rd_list_t *rl, void *ptr);
+void rd_list_free_cb(rd_list_t *rl, void *ptr);
 
 
 /**
@@ -129,7 +134,7 @@ void rd_list_free_cb (rd_list_t *rl, void *ptr);
  * @returns \p elem. If \p elem is NULL the default element for that index
  *          will be returned (for use with set_elems).
  */
-void *rd_list_add (rd_list_t *rl, void *elem);
+void *rd_list_add(rd_list_t *rl, void *elem);
 
 
 /**
@@ -139,7 +144,7 @@ void *rd_list_add (rd_list_t *rl, void *elem);
  * @remark The list will be grown, if needed, any gaps between the current
  *         highest element and \p idx will be set to NULL.
  */
-void rd_list_set (rd_list_t *rl, int idx, void *ptr);
+void rd_list_set(rd_list_t *rl, int idx, void *ptr);
 
 
 /**
@@ -147,14 +152,15 @@ void rd_list_set (rd_list_t *rl, int idx, void *ptr);
  * This is a slow O(n) + memmove operation.
  * Returns the removed element.
  */
-void *rd_list_remove (rd_list_t *rl, void *match_elem);
+void *rd_list_remove(rd_list_t *rl, void *match_elem);
 
 /**
  * Remove element from list using comparator.
  * See rd_list_remove()
  */
-void *rd_list_remove_cmp (rd_list_t *rl, void *match_elem,
-                         int (*cmp) (void *_a, void *_b));
+void *rd_list_remove_cmp(rd_list_t *rl,
+                         void *match_elem,
+                         int (*cmp)(void *_a, void *_b));
 
 
 /**
@@ -162,14 +168,14 @@ void *rd_list_remove_cmp (rd_list_t *rl, void *match_elem,
  *
  * This is a O(1) + memmove operation
  */
-void rd_list_remove_elem (rd_list_t *rl, int idx);
+void rd_list_remove_elem(rd_list_t *rl, int idx);
 
 
 /**
  * @brief Remove and return the last element in the list.
  *
  * @returns the last element, or NULL if list is empty. */
-void *rd_list_pop (rd_list_t *rl);
+void *rd_list_pop(rd_list_t *rl);
 
 
 /**
@@ -179,8 +185,9 @@ void *rd_list_pop (rd_list_t *rl);
  *
  * @sa rd_list_remove()
  */
-int rd_list_remove_multi_cmp (rd_list_t *rl, void *match_elem,
-                               int (*cmp) (void *_a, void *_b));
+int rd_list_remove_multi_cmp(rd_list_t *rl,
+                             void *match_elem,
+                             int (*cmp)(void *_a, void *_b));
 
 
 /**
@@ -189,13 +196,13 @@ int rd_list_remove_multi_cmp (rd_list_t *rl, void *match_elem,
  * To sort a list ascendingly the comparator should implement (a - b)
  * and for descending order implement (b - a).
  */
-void rd_list_sort (rd_list_t *rl, int (*cmp) (const void *, const void *));
+void rd_list_sort(rd_list_t *rl, int (*cmp)(const void *, const void *));
 
 
 /**
  * Empties the list and frees elements (if there is a free_cb).
  */
-void rd_list_clear (rd_list_t *rl);
+void rd_list_clear(rd_list_t *rl);
 
 
 /**
@@ -204,13 +211,13 @@ void rd_list_clear (rd_list_t *rl);
  *
  * If the list was previously allocated with rd_list_new() it will be freed.
  */
-void rd_list_destroy (rd_list_t *rl);
+void rd_list_destroy(rd_list_t *rl);
 
 /**
  * @brief Wrapper for rd_list_destroy() that has same signature as free(3),
  *        allowing it to be used as free_cb for nested lists.
  */
-void rd_list_destroy_free (void *rl);
+void rd_list_destroy_free(void *rl);
 
 
 /**
@@ -222,19 +229,19 @@ void rd_list_destroy_free (void *rl);
  *    while ((obj = rd_list_elem(rl, i++)))
  *        do_something(obj);
  */
-void *rd_list_elem (const rd_list_t *rl, int idx);
+void *rd_list_elem(const rd_list_t *rl, int idx);
 
-#define RD_LIST_FOREACH(elem,listp,idx) \
-        for (idx = 0 ; (elem = rd_list_elem(listp, idx)) ; idx++)
+#define RD_LIST_FOREACH(elem, listp, idx)                                      \
+        for (idx = 0; (elem = rd_list_elem(listp, idx)); idx++)
 
-#define RD_LIST_FOREACH_REVERSE(elem,listp,idx)                         \
-        for (idx = (listp)->rl_cnt-1 ;                                  \
-             idx >= 0 && (elem = rd_list_elem(listp, idx)) ; idx--)
+#define RD_LIST_FOREACH_REVERSE(elem, listp, idx)                              \
+        for (idx = (listp)->rl_cnt - 1;                                        \
+             idx >= 0 && (elem = rd_list_elem(listp, idx)); idx--)
 
 /**
  * Returns the number of elements in list.
  */
-static RD_INLINE RD_UNUSED int rd_list_cnt (const rd_list_t *rl) {
+static RD_INLINE RD_UNUSED int rd_list_cnt(const rd_list_t *rl) {
         return rl->rl_cnt;
 }
 
@@ -254,8 +261,9 @@ static RD_INLINE RD_UNUSED int rd_list_cnt (const rd_list_t *rl) {
  * @remark this is a O(n) scan.
  * @returns the first matching element or NULL.
  */
-int rd_list_index (const rd_list_t *rl, const void *match,
-                   int (*cmp) (const void *, const void *));
+int rd_list_index(const rd_list_t *rl,
+                  const void *match,
+                  int (*cmp)(const void *, const void *));
 
 /**
  * @brief Find element using comparator
@@ -267,20 +275,21 @@ int rd_list_index (const rd_list_t *rl, const void *match,
  *
  * @returns the first matching element or NULL.
  */
-void *rd_list_find (const rd_list_t *rl, const void *match,
-                    int (*cmp) (const void *, const void *));
+void *rd_list_find(const rd_list_t *rl,
+                   const void *match,
+                   int (*cmp)(const void *, const void *));
 
 
 
 /**
  * @returns the first element of the list, or NULL if list is empty.
  */
-void *rd_list_first (const rd_list_t *rl);
+void *rd_list_first(const rd_list_t *rl);
 
 /**
  * @returns the last element of the list, or NULL if list is empty.
  */
-void *rd_list_last (const rd_list_t *rl);
+void *rd_list_last(const rd_list_t *rl);
 
 
 /**
@@ -288,8 +297,8 @@ void *rd_list_last (const rd_list_t *rl);
  *
  * @warning The list MUST be sorted.
  */
-void *rd_list_find_duplicate (const rd_list_t *rl,
-                              int (*cmp) (const void *, const void *));
+void *rd_list_find_duplicate(const rd_list_t *rl,
+                             int (*cmp)(const void *, const void *));
 
 
 /**
@@ -299,36 +308,38 @@ void *rd_list_find_duplicate (const rd_list_t *rl,
  *          > 0 if a was "greater" than b,
  *            0 if a and b are equal.
  */
-int rd_list_cmp (const rd_list_t *a, const rd_list_t *b,
-                 int (*cmp) (const void *, const void *));
+int rd_list_cmp(const rd_list_t *a,
+                const rd_list_t *b,
+                int (*cmp)(const void *, const void *));
 
 /**
  * @brief Simple element pointer comparator
  */
-int rd_list_cmp_ptr (const void *a, const void *b);
+int rd_list_cmp_ptr(const void *a, const void *b);
 
 /**
  * @brief strcmp comparator where the list elements are strings.
  */
-int rd_list_cmp_str (const void *a, const void *b);
+int rd_list_cmp_str(const void *a, const void *b);
 
 
 /**
  * @brief Apply \p cb to each element in list, if \p cb returns 0
  *        the element will be removed (but not freed).
  */
-void rd_list_apply (rd_list_t *rl,
-                    int (*cb) (void *elem, void *opaque), void *opaque);
+void rd_list_apply(rd_list_t *rl,
+                   int (*cb)(void *elem, void *opaque),
+                   void *opaque);
 
 
 
-typedef void *(rd_list_copy_cb_t) (const void *elem, void *opaque);
+typedef void *(rd_list_copy_cb_t)(const void *elem, void *opaque);
 /**
  * @brief Copy list \p src, returning a new list,
  *        using optional \p copy_cb (per elem)
  */
-rd_list_t *rd_list_copy (const rd_list_t *src,
-                         rd_list_copy_cb_t *copy_cb, void *opaque);
+rd_list_t *
+rd_list_copy(const rd_list_t *src, rd_list_copy_cb_t *copy_cb, void *opaque);
 
 
 /**
@@ -337,22 +348,22 @@ rd_list_t *rd_list_copy (const rd_list_t *src,
  * @remark copy_cb() may return NULL in which case no element is added,
  *                   but the copy callback might have done so itself.
  */
-void rd_list_copy_to (rd_list_t *dst, const rd_list_t *src,
-                      void *(*copy_cb) (const void *elem, void *opaque),
-                      void *opaque);
+void rd_list_copy_to(rd_list_t *dst,
+                     const rd_list_t *src,
+                     void *(*copy_cb)(const void *elem, void *opaque),
+                     void *opaque);
 
 
 /**
  * @brief Copy callback to copy elements that are preallocated lists.
  */
-void *rd_list_copy_preallocated (const void *elem, void *opaque);
+void *rd_list_copy_preallocated(const void *elem, void *opaque);
 
 
 /**
  * @brief String copier for rd_list_copy()
  */
-static RD_UNUSED
-void *rd_list_string_copy (const void *elem, void *opaque) {
+static RD_UNUSED void *rd_list_string_copy(const void *elem, void *opaque) {
         return rd_strdup((const char *)elem);
 }
 
@@ -364,7 +375,7 @@ void *rd_list_string_copy (const void *elem, void *opaque) {
  * @remark \p dst will be initialized first.
  * @remark \p src will be emptied.
  */
-void rd_list_move (rd_list_t *dst, rd_list_t *src);
+void rd_list_move(rd_list_t *dst, rd_list_t *src);
 
 
 /**
@@ -380,13 +391,13 @@ void rd_list_move (rd_list_t *dst, rd_list_t *src);
  * @remark The allocation flag of the original \p rl is retained,
  *         do not pass an uninitialized \p rl to this function.
  */
-rd_list_t *rd_list_init_int32 (rd_list_t *rl, int max_size);
+rd_list_t *rd_list_init_int32(rd_list_t *rl, int max_size);
 
 
 /**
  * Debugging: Print list to stdout.
  */
-void rd_list_dump (const char *what, const rd_list_t *rl);
+void rd_list_dump(const char *what, const rd_list_t *rl);
 
 
 
@@ -396,14 +407,14 @@ void rd_list_dump (const char *what, const rd_list_t *rl);
  * @remark Must only be used with preallocated int32_t lists.
  * @remark Allows values to be overwritten.
  */
-void rd_list_set_int32 (rd_list_t *rl, int idx, int32_t val);
+void rd_list_set_int32(rd_list_t *rl, int idx, int32_t val);
 
 /**
  * @returns the int32_t element value at index \p idx
  *
  * @remark Must only be used with preallocated int32_t lists.
  */
-int32_t rd_list_get_int32 (const rd_list_t *rl, int idx);
+int32_t rd_list_get_int32(const rd_list_t *rl, int idx);
 
 /**@}*/
 
