@@ -36,7 +36,7 @@
 
 
 
-int main_0009_mock_cluster (int argc, char **argv) {
+int main_0009_mock_cluster(int argc, char **argv) {
         const char *topic = test_mk_topic_name("0009_mock_cluster", 1);
         rd_kafka_mock_cluster_t *mcluster;
         rd_kafka_t *p, *c;
@@ -69,12 +69,11 @@ int main_0009_mock_cluster (int argc, char **argv) {
         rkt = test_create_producer_topic(p, topic, NULL);
 
         /* Produce */
-        test_produce_msgs(p, rkt, 0, RD_KAFKA_PARTITION_UA, 0, msgcnt,
-                          NULL, 0);
+        test_produce_msgs(p, rkt, 0, RD_KAFKA_PARTITION_UA, 0, msgcnt, NULL, 0);
 
         /* Produce tiny messages */
-        test_produce_msgs(p, rkt, 0, RD_KAFKA_PARTITION_UA, 0, msgcnt,
-                          "hello", 5);
+        test_produce_msgs(p, rkt, 0, RD_KAFKA_PARTITION_UA, 0, msgcnt, "hello",
+                          5);
 
         rd_kafka_topic_destroy(rkt);
 
