@@ -30,7 +30,7 @@
 
 /* Typical include path would be <librdkafka/rdkafka.h>, but this program
  * is built from within the librdkafka source tree and thus differs. */
-#include "rdkafka.h"  /* for Kafka driver */
+#include "rdkafka.h" /* for Kafka driver */
 
 
 /**
@@ -46,48 +46,51 @@
  */
 
 
-int main_0041_fetch_max_bytes (int argc, char **argv) {
-	const char *topic = test_mk_topic_name(__FUNCTION__, 1);
-	const int partition = 0;
-	const int msgcnt = 2*1000;
-	const int MAX_BYTES = 100000;
-	uint64_t testid;
-	rd_kafka_conf_t *conf;
-	rd_kafka_t *rk;
-	rd_kafka_topic_t *rkt;
+int main_0041_fetch_max_bytes(int argc, char **argv) {
+        const char *topic   = test_mk_topic_name(__FUNCTION__, 1);
+        const int partition = 0;
+        const int msgcnt    = 2 * 1000;
+        const int MAX_BYTES = 100000;
+        uint64_t testid;
+        rd_kafka_conf_t *conf;
+        rd_kafka_t *rk;
+        rd_kafka_topic_t *rkt;
 
-	test_conf_init(NULL, NULL, 60);
-	
-	testid = test_id_generate();
-	rk = test_create_producer();
-	rkt = test_create_producer_topic(rk, topic, NULL);
+        test_conf_init(NULL, NULL, 60);
 
-	test_produce_msgs(rk, rkt, testid, partition, 0, msgcnt/2, NULL, MAX_BYTES/10);
-	test_produce_msgs(rk, rkt, testid, partition, msgcnt/2, msgcnt/2, NULL, MAX_BYTES*5);
+        testid = test_id_generate();
+        rk     = test_create_producer();
+        rkt    = test_create_producer_topic(rk, topic, NULL);
 
-	rd_kafka_topic_destroy(rkt);
-	rd_kafka_destroy(rk);
+        test_produce_msgs(rk, rkt, testid, partition, 0, msgcnt / 2, NULL,
+                          MAX_BYTES / 10);
+        test_produce_msgs(rk, rkt, testid, partition, msgcnt / 2, msgcnt / 2,
+                          NULL, MAX_BYTES * 5);
 
-	TEST_SAY("Creating consumer\n");
-	test_conf_init(&conf, NULL, 0);
+        rd_kafka_topic_destroy(rkt);
+        rd_kafka_destroy(rk);
 
-	test_conf_set(conf, "fetch.message.max.bytes", tsprintf("%d", MAX_BYTES));
+        TEST_SAY("Creating consumer\n");
+        test_conf_init(&conf, NULL, 0);
+
+        test_conf_set(conf, "fetch.message.max.bytes",
+                      tsprintf("%d", MAX_BYTES));
 
         /* This test may be slower when running with SSL or Helgrind,
          * restart the timeout. */
         test_timeout_set(60);
 
-	rk = test_create_consumer(NULL, NULL, conf, NULL);
-	rkt = rd_kafka_topic_new(rk, topic, NULL);
+        rk  = test_create_consumer(NULL, NULL, conf, NULL);
+        rkt = rd_kafka_topic_new(rk, topic, NULL);
 
-	test_consumer_start("CONSUME", rkt, partition,
-			    RD_KAFKA_OFFSET_BEGINNING);
-	test_consume_msgs("CONSUME", rkt, testid, partition, TEST_NO_SEEK,
-			  0, msgcnt, 1);
-	test_consumer_stop("CONSUME", rkt, partition);
+        test_consumer_start("CONSUME", rkt, partition,
+                            RD_KAFKA_OFFSET_BEGINNING);
+        test_consume_msgs("CONSUME", rkt, testid, partition, TEST_NO_SEEK, 0,
+                          msgcnt, 1);
+        test_consumer_stop("CONSUME", rkt, partition);
 
-	rd_kafka_topic_destroy(rkt);
-	rd_kafka_destroy(rk);
+        rd_kafka_topic_destroy(rkt);
+        rd_kafka_destroy(rk);
 
-	return 0;
+        return 0;
 }
