@@ -36,42 +36,42 @@
 
 
 
-static void test_producer_no_connection (void) {
-	rd_kafka_t *rk;
-	rd_kafka_conf_t *conf;
-	rd_kafka_topic_t *rkt;
-	int i;
-	const int partition_cnt = 2;
-	int msgcnt = 0;
-	test_timing_t t_destroy;
+static void test_producer_no_connection(void) {
+        rd_kafka_t *rk;
+        rd_kafka_conf_t *conf;
+        rd_kafka_topic_t *rkt;
+        int i;
+        const int partition_cnt = 2;
+        int msgcnt              = 0;
+        test_timing_t t_destroy;
 
-	test_conf_init(&conf, NULL, 20);
+        test_conf_init(&conf, NULL, 20);
 
-	test_conf_set(conf, "bootstrap.servers", NULL);
+        test_conf_set(conf, "bootstrap.servers", NULL);
 
-	rk = test_create_handle(RD_KAFKA_PRODUCER, conf);
-	rkt = test_create_topic_object(rk, __FUNCTION__,
-				       "message.timeout.ms", "5000", NULL);
+        rk  = test_create_handle(RD_KAFKA_PRODUCER, conf);
+        rkt = test_create_topic_object(rk, __FUNCTION__, "message.timeout.ms",
+                                       "5000", NULL);
 
-	test_produce_msgs_nowait(rk, rkt, 0, RD_KAFKA_PARTITION_UA, 0, 100,
-				 NULL, 100, 0, &msgcnt);
-	for (i = 0 ; i < partition_cnt ; i++)
-		test_produce_msgs_nowait(rk, rkt, 0, i,
-					 0, 100, NULL, 100, 0, &msgcnt);
+        test_produce_msgs_nowait(rk, rkt, 0, RD_KAFKA_PARTITION_UA, 0, 100,
+                                 NULL, 100, 0, &msgcnt);
+        for (i = 0; i < partition_cnt; i++)
+                test_produce_msgs_nowait(rk, rkt, 0, i, 0, 100, NULL, 100, 0,
+                                         &msgcnt);
 
-	rd_kafka_poll(rk, 1000);
+        rd_kafka_poll(rk, 1000);
 
-	TEST_SAY("%d messages in queue\n", rd_kafka_outq_len(rk));
+        TEST_SAY("%d messages in queue\n", rd_kafka_outq_len(rk));
 
-	rd_kafka_topic_destroy(rkt);
+        rd_kafka_topic_destroy(rkt);
 
-	TIMING_START(&t_destroy, "rd_kafka_destroy()");
-	rd_kafka_destroy(rk);
-	TIMING_STOP(&t_destroy);
+        TIMING_START(&t_destroy, "rd_kafka_destroy()");
+        rd_kafka_destroy(rk);
+        TIMING_STOP(&t_destroy);
 }
 
-int main_0043_no_connection (int argc, char **argv) {
-	test_producer_no_connection();
+int main_0043_no_connection(int argc, char **argv) {
+        test_producer_no_connection();
 
         return 0;
 }
