@@ -49,32 +49,31 @@ static const char *stats_schema_path = "../src/statistics_schema.json";
  */
 class TestSchemaValidator {
  public:
-  TestSchemaValidator () {
-
+  TestSchemaValidator() {
   }
-  TestSchemaValidator (const std::string schema_path) {
+  TestSchemaValidator(const std::string schema_path) {
     /* Read schema from file */
     schema_path_ = schema_path;
 
     std::ifstream f(schema_path.c_str());
     if (!f.is_open())
-            Test::Fail(tostr() << "Failed to open schema " << schema_path <<
-                       ": " << strerror(errno));
+      Test::Fail(tostr() << "Failed to open schema " << schema_path << ": "
+                         << strerror(errno));
     std::string schema_str((std::istreambuf_iterator<char>(f)),
                            (std::istreambuf_iterator<char>()));
 
     /* Parse schema */
     sd_ = new rapidjson::Document();
     if (sd_->Parse(schema_str.c_str()).HasParseError())
-      Test::Fail(tostr() << "Failed to parse statistics schema: " <<
-                 rapidjson::GetParseError_En(sd_->GetParseError()) <<
-                 " at " << sd_->GetErrorOffset());
+      Test::Fail(tostr() << "Failed to parse statistics schema: "
+                         << rapidjson::GetParseError_En(sd_->GetParseError())
+                         << " at " << sd_->GetErrorOffset());
 
-    schema_ = new rapidjson::SchemaDocument(*sd_);
+    schema_    = new rapidjson::SchemaDocument(*sd_);
     validator_ = new rapidjson::SchemaValidator(*schema_);
   }
 
-  ~TestSchemaValidator () {
+  ~TestSchemaValidator() {
     if (sd_)
       delete sd_;
     if (schema_)
@@ -83,29 +82,30 @@ class TestSchemaValidator {
       delete validator_;
   }
 
-  void validate (const std::string &json_doc) {
+  void validate(const std::string &json_doc) {
     /* Parse JSON to validate */
     rapidjson::Document d;
     if (d.Parse(json_doc.c_str()).HasParseError())
-      Test::Fail(tostr() << "Failed to parse stats JSON: " <<
-                 rapidjson::GetParseError_En(d.GetParseError()) <<
-                 " at " << d.GetErrorOffset());
+      Test::Fail(tostr() << "Failed to parse stats JSON: "
+                         << rapidjson::GetParseError_En(d.GetParseError())
+                         << " at " << d.GetErrorOffset());
 
     /* Validate using schema */
     if (!d.Accept(*validator_)) {
-
       rapidjson::StringBuffer sb;
 
       validator_->GetInvalidSchemaPointer().StringifyUriFragment(sb);
       Test::Say(tostr() << "Schema: " << sb.GetString() << "\n");
-      Test::Say(tostr() << "Invalid keyword: " << validator_->GetInvalidSchemaKeyword() << "\n");
+      Test::Say(tostr() << "Invalid keyword: "
+                        << validator_->GetInvalidSchemaKeyword() << "\n");
       sb.Clear();
 
       validator_->GetInvalidDocumentPointer().StringifyUriFragment(sb);
       Test::Say(tostr() << "Invalid document: " << sb.GetString() << "\n");
       sb.Clear();
 
-      Test::Fail(tostr() << "JSON validation using schema " << schema_path_ << " failed");
+      Test::Fail(tostr() << "JSON validation using schema " << schema_path_
+                         << " failed");
     }
 
     Test::Say(3, "JSON document validated using schema " + schema_path_ + "\n");
@@ -124,16 +124,15 @@ class TestSchemaValidator {
 /* Dummy validator doing nothing when RapidJSON is unavailable */
 class TestSchemaValidator {
  public:
-  TestSchemaValidator () {
-
+  TestSchemaValidator() {
   }
-  TestSchemaValidator (const std::string schema_path) {
+  TestSchemaValidator(const std::string schema_path) {
   }
 
-  ~TestSchemaValidator () {
+  ~TestSchemaValidator() {
   }
 
-  void validate (const std::string &json_doc) {
+  void validate(const std::string &json_doc) {
   }
 };
 
@@ -141,28 +140,27 @@ class TestSchemaValidator {
 
 class myEventCb : public RdKafka::EventCb {
  public:
-  myEventCb(const std::string schema_path):
+  myEventCb(const std::string schema_path) :
       validator_(TestSchemaValidator(schema_path)) {
     stats_cnt = 0;
   }
 
   int stats_cnt;
-  std::string last;  /**< Last stats document */
+  std::string last; /**< Last stats document */
 
-  void event_cb (RdKafka::Event &event) {
-    switch (event.type())
-    {
-      case RdKafka::Event::EVENT_STATS:
-        if (!(stats_cnt % 10))
-          Test::Say(tostr() << "Stats (#" << stats_cnt << "): " <<
-                    event.str() << "\n");
-        if (event.str().length() > 20)
-          stats_cnt += 1;
-        validator_.validate(event.str());
-        last = event.str();
-        break;
-      default:
-        break;
+  void event_cb(RdKafka::Event &event) {
+    switch (event.type()) {
+    case RdKafka::Event::EVENT_STATS:
+      if (!(stats_cnt % 10))
+        Test::Say(tostr() << "Stats (#" << stats_cnt << "): " << event.str()
+                          << "\n");
+      if (event.str().length() > 20)
+        stats_cnt += 1;
+      validator_.validate(event.str());
+      last = event.str();
+      break;
+    default:
+      break;
     }
   }
 
@@ -174,20 +172,21 @@ class myEventCb : public RdKafka::EventCb {
 /**
  * @brief Verify that stats are emitted according to statistics.interval.ms
  */
-void test_stats_timing () {
+void test_stats_timing() {
   RdKafka::Conf *conf = RdKafka::Conf::create(RdKafka::Conf::CONF_GLOBAL);
-  myEventCb my_event = myEventCb(stats_schema_path);
+  myEventCb my_event  = myEventCb(stats_schema_path);
   std::string errstr;
 
-  if (conf->set("statistics.interval.ms", "100", errstr) != RdKafka::Conf::CONF_OK)
-          Test::Fail(errstr);
+  if (conf->set("statistics.interval.ms", "100", errstr) !=
+      RdKafka::Conf::CONF_OK)
+    Test::Fail(errstr);
 
   if (conf->set("event_cb", &my_event, errstr) != RdKafka::Conf::CONF_OK)
-          Test::Fail(errstr);
+    Test::Fail(errstr);
 
   RdKafka::Producer *p = RdKafka::Producer::create(conf, errstr);
   if (!p)
-          Test::Fail("Failed to create Producer: " + errstr);
+    Test::Fail("Failed to create Producer: " + errstr);
   delete conf;
 
   int64_t t_start = test_clock();
@@ -195,22 +194,24 @@ void test_stats_timing () {
   while (my_event.stats_cnt < 12)
     p->poll(1000);
 
-  int elapsed = (int)((test_clock() - t_start) / 1000);
+  int elapsed             = (int)((test_clock() - t_start) / 1000);
   const int expected_time = 1200;
 
-  Test::Say(tostr() << my_event.stats_cnt << " (expected 12) stats callbacks received in " <<
-            elapsed << "ms (expected " << expected_time << "ms +-25%)\n");
+  Test::Say(tostr() << my_event.stats_cnt
+                    << " (expected 12) stats callbacks received in " << elapsed
+                    << "ms (expected " << expected_time << "ms +-25%)\n");
 
-  if (elapsed < expected_time * 0.75 ||
-      elapsed > expected_time * 1.25) {
+  if (elapsed < expected_time * 0.75 || elapsed > expected_time * 1.25) {
     /* We can't rely on CIs giving our test job enough CPU to finish
      * in time, so don't error out even if the time is outside the window */
     if (test_on_ci)
-      Test::Say(tostr() << "WARNING: Elapsed time " << elapsed << "ms outside +-25% window (" <<
-                expected_time << "ms), cnt " << my_event.stats_cnt);
+      Test::Say(tostr() << "WARNING: Elapsed time " << elapsed
+                        << "ms outside +-25% window (" << expected_time
+                        << "ms), cnt " << my_event.stats_cnt);
     else
-      Test::Fail(tostr() << "Elapsed time " << elapsed << "ms outside +-25% window (" <<
-                 expected_time << "ms), cnt " << my_event.stats_cnt);
+      Test::Fail(tostr() << "Elapsed time " << elapsed
+                         << "ms outside +-25% window (" << expected_time
+                         << "ms), cnt " << my_event.stats_cnt);
   }
   delete p;
 }
@@ -223,67 +224,68 @@ void test_stats_timing () {
  * @brief Expected partition stats
  */
 struct exp_part_stats {
-  std::string topic;   /**< Topic */
-  int32_t part;        /**< Partition id */
-  int     msgcnt;      /**< Expected message count */
-  int     msgsize;     /**< Expected per message size.
-                        *   This includes both key and value lengths */
+  std::string topic; /**< Topic */
+  int32_t part;      /**< Partition id */
+  int msgcnt;        /**< Expected message count */
+  int msgsize;       /**< Expected per message size.
+                      *   This includes both key and value lengths */
 
   /* Calculated */
-  int64_t totsize;     /**< Message size sum */
+  int64_t totsize; /**< Message size sum */
 };
 
 /**
  * @brief Verify end-to-end producer and consumer stats.
  */
-static void verify_e2e_stats (const std::string &prod_stats,
-                              const std::string &cons_stats,
-                              struct exp_part_stats *exp_parts, int partcnt) {
+static void verify_e2e_stats(const std::string &prod_stats,
+                             const std::string &cons_stats,
+                             struct exp_part_stats *exp_parts,
+                             int partcnt) {
   /**
    * Parse JSON stats
    * These documents are already validated in the Event callback.
    */
   rapidjson::Document p;
-  if (p.Parse<rapidjson::kParseValidateEncodingFlag>(prod_stats.c_str()).HasParseError())
-    Test::Fail(tostr() << "Failed to parse producer stats JSON: " <<
-               rapidjson::GetParseError_En(p.GetParseError()) <<
-               " at " << p.GetErrorOffset());
+  if (p.Parse<rapidjson::kParseValidateEncodingFlag>(prod_stats.c_str())
+          .HasParseError())
+    Test::Fail(tostr() << "Failed to parse producer stats JSON: "
+                       << rapidjson::GetParseError_En(p.GetParseError())
+                       << " at " << p.GetErrorOffset());
 
   rapidjson::Document c;
-  if (c.Parse<rapidjson::kParseValidateEncodingFlag>(cons_stats.c_str()).HasParseError())
-    Test::Fail(tostr() << "Failed to parse consumer stats JSON: " <<
-               rapidjson::GetParseError_En(c.GetParseError()) <<
-               " at " << c.GetErrorOffset());
+  if (c.Parse<rapidjson::kParseValidateEncodingFlag>(cons_stats.c_str())
+          .HasParseError())
+    Test::Fail(tostr() << "Failed to parse consumer stats JSON: "
+                       << rapidjson::GetParseError_En(c.GetParseError())
+                       << " at " << c.GetErrorOffset());
 
   assert(p.HasMember("name"));
   assert(c.HasMember("name"));
   assert(p.HasMember("type"));
   assert(c.HasMember("type"));
 
-  Test::Say(tostr() << "Verifying stats from Producer " << p["name"].GetString() <<
-            " and Consumer " << c["name"].GetString() << "\n");
+  Test::Say(tostr() << "Verifying stats from Producer " << p["name"].GetString()
+                    << " and Consumer " << c["name"].GetString() << "\n");
 
   assert(!strcmp(p["type"].GetString(), "producer"));
   assert(!strcmp(c["type"].GetString(), "consumer"));
 
-  int64_t exp_tot_txmsgs = 0;
+  int64_t exp_tot_txmsgs      = 0;
   int64_t exp_tot_txmsg_bytes = 0;
-  int64_t exp_tot_rxmsgs = 0;
+  int64_t exp_tot_rxmsgs      = 0;
   int64_t exp_tot_rxmsg_bytes = 0;
 
-  for (int part = 0 ; part < partcnt ; part++) {
-
+  for (int part = 0; part < partcnt; part++) {
     /*
      * Find partition stats.
      */
 
     /* Construct the partition path. */
     char path[256];
-    rd_snprintf(path, sizeof(path),
-                "/topics/%s/partitions/%d",
+    rd_snprintf(path, sizeof(path), "/topics/%s/partitions/%d",
                 exp_parts[part].topic.c_str(), exp_parts[part].part);
-    Test::Say(tostr() << "Looking up partition " << exp_parts[part].part <<
-              " with path " << path << "\n");
+    Test::Say(tostr() << "Looking up partition " << exp_parts[part].part
+                      << " with path " << path << "\n");
 
     /* Even though GetValueByPointer() takes a "char[]" it can only be used
      * with perfectly sized char buffers or string literals since it
@@ -293,13 +295,13 @@ static void verify_e2e_stats (const std::string &prod_stats,
 
     rapidjson::Value *pp = rapidjson::GetValueByPointer(p, jpath);
     if (!pp)
-      Test::Fail(tostr() << "Producer: could not find " << path <<
-                 " in " << prod_stats << "\n");
+      Test::Fail(tostr() << "Producer: could not find " << path << " in "
+                         << prod_stats << "\n");
 
     rapidjson::Value *cp = rapidjson::GetValueByPointer(c, jpath);
     if (!pp)
-      Test::Fail(tostr() << "Consumer: could not find " << path <<
-                 " in " << cons_stats << "\n");
+      Test::Fail(tostr() << "Consumer: could not find " << path << " in "
+                         << cons_stats << "\n");
 
     assert(pp->HasMember("partition"));
     assert(pp->HasMember("txmsgs"));
@@ -311,9 +313,9 @@ static void verify_e2e_stats (const std::string &prod_stats,
 
     Test::Say(tostr() << "partition: " << (*pp)["partition"].GetInt() << "\n");
 
-    int64_t txmsgs = (*pp)["txmsgs"].GetInt();
+    int64_t txmsgs  = (*pp)["txmsgs"].GetInt();
     int64_t txbytes = (*pp)["txbytes"].GetInt();
-    int64_t rxmsgs = (*cp)["rxmsgs"].GetInt();
+    int64_t rxmsgs  = (*cp)["rxmsgs"].GetInt();
     int64_t rxbytes = (*cp)["rxbytes"].GetInt();
 
     exp_tot_txmsgs += txmsgs;
@@ -321,12 +323,18 @@ static void verify_e2e_stats (const std::string &prod_stats,
     exp_tot_rxmsgs += rxmsgs;
     exp_tot_rxmsg_bytes += rxbytes;
 
-    Test::Say(tostr() << "Producer partition: " << (*pp)["partition"].GetInt() << ": " <<
-              "txmsgs: " << txmsgs << " vs " << exp_parts[part].msgcnt << ", " <<
-              "txbytes: " << txbytes << " vs " << exp_parts[part].totsize << "\n");
-    Test::Say(tostr() << "Consumer partition: " << (*cp)["partition"].GetInt() << ": " <<
-              "rxmsgs: " << rxmsgs << " vs " << exp_parts[part].msgcnt << ", " <<
-              "rxbytes: " << rxbytes << " vs " << exp_parts[part].totsize << "\n");
+    Test::Say(tostr() << "Producer partition: " << (*pp)["partition"].GetInt()
+                      << ": "
+                      << "txmsgs: " << txmsgs << " vs "
+                      << exp_parts[part].msgcnt << ", "
+                      << "txbytes: " << txbytes << " vs "
+                      << exp_parts[part].totsize << "\n");
+    Test::Say(tostr() << "Consumer partition: " << (*cp)["partition"].GetInt()
+                      << ": "
+                      << "rxmsgs: " << rxmsgs << " vs "
+                      << exp_parts[part].msgcnt << ", "
+                      << "rxbytes: " << rxbytes << " vs "
+                      << exp_parts[part].totsize << "\n");
   }
 
   /* Check top-level total stats */
@@ -336,18 +344,21 @@ static void verify_e2e_stats (const std::string &prod_stats,
   assert(p.HasMember("rxmsgs"));
   assert(p.HasMember("rxmsg_bytes"));
 
-  int64_t tot_txmsgs = p["txmsgs"].GetInt();
+  int64_t tot_txmsgs      = p["txmsgs"].GetInt();
   int64_t tot_txmsg_bytes = p["txmsg_bytes"].GetInt();
-  int64_t tot_rxmsgs = c["rxmsgs"].GetInt();
+  int64_t tot_rxmsgs      = c["rxmsgs"].GetInt();
   int64_t tot_rxmsg_bytes = c["rxmsg_bytes"].GetInt();
 
-  Test::Say(tostr() << "Producer total: " <<
-            "txmsgs: " << tot_txmsgs << " vs " << exp_tot_txmsgs << ", " <<
-            "txbytes: " << tot_txmsg_bytes << " vs " << exp_tot_txmsg_bytes << "\n");
-  Test::Say(tostr() << "Consumer total: " <<
-            "rxmsgs: " << tot_rxmsgs << " vs " << exp_tot_rxmsgs << ", " <<
-            "rxbytes: " << tot_rxmsg_bytes << " vs " << exp_tot_rxmsg_bytes << "\n");
-
+  Test::Say(tostr() << "Producer total: "
+                    << "txmsgs: " << tot_txmsgs << " vs " << exp_tot_txmsgs
+                    << ", "
+                    << "txbytes: " << tot_txmsg_bytes << " vs "
+                    << exp_tot_txmsg_bytes << "\n");
+  Test::Say(tostr() << "Consumer total: "
+                    << "rxmsgs: " << tot_rxmsgs << " vs " << exp_tot_rxmsgs
+                    << ", "
+                    << "rxbytes: " << tot_rxmsg_bytes << " vs "
+                    << exp_tot_rxmsg_bytes << "\n");
 }
 
 /**
@@ -359,7 +370,7 @@ static void verify_e2e_stats (const std::string &prod_stats,
  *
  * Requires RapidJSON (for parsing the stats).
  */
-static void test_stats () {
+static void test_stats() {
   std::string errstr;
   RdKafka::Conf *conf;
   myEventCb producer_event(stats_schema_path);
@@ -368,26 +379,27 @@ static void test_stats () {
   std::string topic = Test::mk_topic_name("0053_stats", 1);
 
   const int partcnt = 2;
-  int msgcnt = (test_quick ? 10 : 100) * partcnt;
-  const int msgsize = 6*1024;
+  int msgcnt        = (test_quick ? 10 : 100) * partcnt;
+  const int msgsize = 6 * 1024;
 
   /*
    * Common config for producer and consumer
    */
   Test::conf_init(&conf, NULL, 60);
-  if (conf->set("statistics.interval.ms", "1000", errstr) != RdKafka::Conf::CONF_OK)
-          Test::Fail(errstr);
+  if (conf->set("statistics.interval.ms", "1000", errstr) !=
+      RdKafka::Conf::CONF_OK)
+    Test::Fail(errstr);
 
 
   /*
    * Create Producer
    */
   if (conf->set("event_cb", &producer_event, errstr) != RdKafka::Conf::CONF_OK)
-          Test::Fail(errstr);
+    Test::Fail(errstr);
 
   RdKafka::Producer *p = RdKafka::Producer::create(conf, errstr);
   if (!p)
-          Test::Fail("Failed to create Producer: " + errstr);
+    Test::Fail("Failed to create Producer: " + errstr);
 
 
   /*
@@ -397,7 +409,7 @@ static void test_stats () {
   conf->set("auto.offset.reset", "earliest", errstr);
   conf->set("enable.partition.eof", "false", errstr);
   if (conf->set("event_cb", &consumer_event, errstr) != RdKafka::Conf::CONF_OK)
-          Test::Fail(errstr);
+    Test::Fail(errstr);
 
   RdKafka::KafkaConsumer *c = RdKafka::KafkaConsumer::create(conf, errstr);
   if (!c)
@@ -409,15 +421,15 @@ static void test_stats () {
    * since there will be no topics now) and expected partitions
    * for later verification.
    */
-  std::vector<RdKafka::TopicPartition*> toppars;
+  std::vector<RdKafka::TopicPartition *> toppars;
   struct exp_part_stats exp_parts[partcnt] = {};
 
-  for (int32_t part = 0 ; part < (int32_t)partcnt ; part++) {
-    toppars.push_back(RdKafka::TopicPartition::create(topic, part,
-                                                      RdKafka::Topic::OFFSET_BEGINNING));
-    exp_parts[part].topic = topic;
-    exp_parts[part].part = part;
-    exp_parts[part].msgcnt = msgcnt / partcnt;
+  for (int32_t part = 0; part < (int32_t)partcnt; part++) {
+    toppars.push_back(RdKafka::TopicPartition::create(
+        topic, part, RdKafka::Topic::OFFSET_BEGINNING));
+    exp_parts[part].topic   = topic;
+    exp_parts[part].part    = part;
+    exp_parts[part].msgcnt  = msgcnt / partcnt;
     exp_parts[part].msgsize = msgsize;
     exp_parts[part].totsize = 0;
   }
@@ -430,13 +442,12 @@ static void test_stats () {
   char key[256];
   char *buf = (char *)malloc(msgsize);
 
-  for (int32_t part = 0 ; part < (int32_t)partcnt ; part++) {
-    for (int i = 0 ; i < msgcnt / partcnt ; i++) {
+  for (int32_t part = 0; part < (int32_t)partcnt; part++) {
+    for (int i = 0; i < msgcnt / partcnt; i++) {
       test_prepare_msg(testid, part, i, buf, msgsize, key, sizeof(key));
-      RdKafka::ErrorCode err = p->produce(topic, part,
-                                          RdKafka::Producer::RK_MSG_COPY,
-                                          buf, msgsize, key, sizeof(key),
-                                          -1, NULL);
+      RdKafka::ErrorCode err =
+          p->produce(topic, part, RdKafka::Producer::RK_MSG_COPY, buf, msgsize,
+                     key, sizeof(key), -1, NULL);
       if (err)
         Test::Fail("Produce failed: " + RdKafka::err2str(err));
       exp_parts[part].totsize += msgsize + sizeof(key);
@@ -448,11 +459,11 @@ static void test_stats () {
 
   Test::Say("Waiting for final message delivery\n");
   /* Wait for delivery */
-  p->flush(15*1000);
+  p->flush(15 * 1000);
 
   /*
-  * Start consuming partitions
-  */
+   * Start consuming partitions
+   */
   c->assign(toppars);
   RdKafka::TopicPartition::destroy(toppars);
 
@@ -490,14 +501,14 @@ static void test_stats () {
    */
   prev_cnt = consumer_event.stats_cnt;
   while (prev_cnt + 2 >= consumer_event.stats_cnt) {
-    Test::Say(tostr() << "Waiting for final consumer stats event: " <<
-              consumer_event.stats_cnt << "\n");
+    Test::Say(tostr() << "Waiting for final consumer stats event: "
+                      << consumer_event.stats_cnt << "\n");
     c->poll(100);
   }
 
 
-  verify_e2e_stats(producer_event.last, consumer_event.last,
-                   exp_parts, partcnt);
+  verify_e2e_stats(producer_event.last, consumer_event.last, exp_parts,
+                   partcnt);
 
 
   c->close();
@@ -508,17 +519,17 @@ static void test_stats () {
 #endif
 
 extern "C" {
-  int main_0053_stats_timing (int argc, char **argv) {
-    test_stats_timing();
-    return 0;
-  }
+int main_0053_stats_timing(int argc, char **argv) {
+  test_stats_timing();
+  return 0;
+}
 
-  int main_0053_stats (int argc, char **argv) {
+int main_0053_stats(int argc, char **argv) {
 #if WITH_RAPIDJSON
-    test_stats();
+  test_stats();
 #else
-    Test::Skip("RapidJSON >=1.1.0 not available\n");
+  Test::Skip("RapidJSON >=1.1.0 not available\n");
 #endif
-    return 0;
-  }
+  return 0;
+}
 }
