@@ -38,9 +38,9 @@
  */
 
 
-static void do_test_empty_topic_consumer () {
+static void do_test_empty_topic_consumer() {
   std::string errstr;
-  std::string topic = Test::mk_topic_name("0067_empty_topic", 1);
+  std::string topic       = Test::mk_topic_name("0067_empty_topic", 1);
   const int32_t partition = 0;
 
   RdKafka::Conf *conf;
@@ -53,39 +53,42 @@ static void do_test_empty_topic_consumer () {
   /* Create simple consumer */
   RdKafka::Consumer *consumer = RdKafka::Consumer::create(conf, errstr);
   if (!consumer)
-          Test::Fail("Failed to create Consumer: " + errstr);
+    Test::Fail("Failed to create Consumer: " + errstr);
 
   RdKafka::Topic *rkt = RdKafka::Topic::create(consumer, topic, NULL, errstr);
   if (!rkt)
-          Test::Fail("Simple Topic failed: " + errstr);
+    Test::Fail("Simple Topic failed: " + errstr);
 
 
   /* Create the topic through a metadata request. */
   Test::Say("Creating empty topic " + topic + "\n");
   RdKafka::Metadata *md;
-  RdKafka::ErrorCode err = consumer->metadata(false, rkt, &md,
-                                              tmout_multip(10*1000));
+  RdKafka::ErrorCode err =
+      consumer->metadata(false, rkt, &md, tmout_multip(10 * 1000));
   if (err)
-          Test::Fail("Failed to create topic " + topic + ": " + RdKafka::err2str(err));
+    Test::Fail("Failed to create topic " + topic + ": " +
+               RdKafka::err2str(err));
   delete md;
 
   /* Start consumer */
   err = consumer->start(rkt, partition, RdKafka::Topic::OFFSET_BEGINNING);
   if (err)
-          Test::Fail("Consume start() failed: " + RdKafka::err2str(err));
+    Test::Fail("Consume start() failed: " + RdKafka::err2str(err));
 
   /* Consume using legacy consumer, should give an EOF and nothing else. */
   Test::Say("Simple Consumer: consuming\n");
-  RdKafka::Message *msg = consumer->consume(rkt, partition,
-                                            tmout_multip(10 * 1000));
+  RdKafka::Message *msg =
+      consumer->consume(rkt, partition, tmout_multip(10 * 1000));
   if (msg->err() != RdKafka::ERR__PARTITION_EOF)
-          Test::Fail("Simple consume() expected EOF, got " + RdKafka::err2str(msg->err()));
+    Test::Fail("Simple consume() expected EOF, got " +
+               RdKafka::err2str(msg->err()));
   delete msg;
 
   /* Nothing else should come now, just a consume() timeout */
   msg = consumer->consume(rkt, partition, 1 * 1000);
   if (msg->err() != RdKafka::ERR__TIMED_OUT)
-          Test::Fail("Simple consume() expected timeout, got " + RdKafka::err2str(msg->err()));
+    Test::Fail("Simple consume() expected timeout, got " +
+               RdKafka::err2str(msg->err()));
   delete msg;
 
   consumer->stop(rkt, partition);
@@ -103,29 +106,32 @@ static void do_test_empty_topic_consumer () {
   Test::conf_set(conf, "enable.partition.eof", "true");
   Test::conf_set(conf, "allow.auto.create.topics", "true");
 
-  RdKafka::KafkaConsumer *kconsumer = RdKafka::KafkaConsumer::create(conf, errstr);
+  RdKafka::KafkaConsumer *kconsumer =
+      RdKafka::KafkaConsumer::create(conf, errstr);
   if (!kconsumer)
-          Test::Fail("Failed to create KafkaConsumer: " + errstr);
+    Test::Fail("Failed to create KafkaConsumer: " + errstr);
 
-  std::vector<RdKafka::TopicPartition*> part;
+  std::vector<RdKafka::TopicPartition *> part;
   part.push_back(RdKafka::TopicPartition::create(topic, partition));
 
   err = kconsumer->assign(part);
   if (err)
-          Test::Fail("assign() failed: " + RdKafka::err2str(err));
+    Test::Fail("assign() failed: " + RdKafka::err2str(err));
 
   RdKafka::TopicPartition::destroy(part);
 
   Test::Say("KafkaConsumer: consuming\n");
   msg = kconsumer->consume(tmout_multip(5 * 1000));
   if (msg->err() != RdKafka::ERR__PARTITION_EOF)
-          Test::Fail("KafkaConsumer consume() expected EOF, got " + RdKafka::err2str(msg->err()));
+    Test::Fail("KafkaConsumer consume() expected EOF, got " +
+               RdKafka::err2str(msg->err()));
   delete msg;
 
   /* Nothing else should come now, just a consume() timeout */
   msg = kconsumer->consume(1 * 1000);
   if (msg->err() != RdKafka::ERR__TIMED_OUT)
-          Test::Fail("KafkaConsumer consume() expected timeout, got " + RdKafka::err2str(msg->err()));
+    Test::Fail("KafkaConsumer consume() expected timeout, got " +
+               RdKafka::err2str(msg->err()));
   delete msg;
 
   kconsumer->close();
@@ -135,8 +141,8 @@ static void do_test_empty_topic_consumer () {
 }
 
 extern "C" {
-  int main_0067_empty_topic (int argc, char **argv) {
-    do_test_empty_topic_consumer();
-    return 0;
-  }
+int main_0067_empty_topic(int argc, char **argv) {
+  do_test_empty_topic_consumer();
+  return 0;
+}
 }
