@@ -41,15 +41,15 @@
  * @brief Sockem connect, called from **internal librdkafka thread** through
  *        librdkafka's connect_cb
  */
-static int connect_cb (struct test *test, sockem_t *skm, const char *id) {
+static int connect_cb(struct test *test, sockem_t *skm, const char *id) {
 
         /* Let delay be high to trigger the local timeout */
         sockem_set(skm, "delay", 10000, NULL);
         return 0;
 }
 
-static int is_fatal_cb (rd_kafka_t *rk, rd_kafka_resp_err_t err,
-                        const char *reason) {
+static int
+is_fatal_cb(rd_kafka_t *rk, rd_kafka_resp_err_t err, const char *reason) {
         /* Ignore connectivity errors since we'll be bringing down
          * .. connectivity.
          * SASL auther will think a connection-down even in the auth
@@ -63,19 +63,20 @@ static int is_fatal_cb (rd_kafka_t *rk, rd_kafka_resp_err_t err,
         return 1;
 }
 
-static int msg_dr_cnt = 0;
+static int msg_dr_cnt      = 0;
 static int msg_dr_fail_cnt = 0;
 
-static void dr_msg_cb (rd_kafka_t *rk, const rd_kafka_message_t *rkmessage,
-                       void *opaque) {
+static void
+dr_msg_cb(rd_kafka_t *rk, const rd_kafka_message_t *rkmessage, void *opaque) {
         msg_dr_cnt++;
         if (rkmessage->err != RD_KAFKA_RESP_ERR__MSG_TIMED_OUT)
-                TEST_FAIL_LATER("Expected message to fail with MSG_TIMED_OUT, "
-                                "got: %s",
-                                rd_kafka_err2str(rkmessage->err));
+                TEST_FAIL_LATER(
+                    "Expected message to fail with MSG_TIMED_OUT, "
+                    "got: %s",
+                    rd_kafka_err2str(rkmessage->err));
         else {
                 TEST_ASSERT_LATER(rd_kafka_message_status(rkmessage) ==
-                                  RD_KAFKA_MSG_STATUS_POSSIBLY_PERSISTED,
+                                      RD_KAFKA_MSG_STATUS_POSSIBLY_PERSISTED,
                                   "Message should have status "
                                   "PossiblyPersisted (%d), not %d",
                                   RD_KAFKA_MSG_STATUS_POSSIBLY_PERSISTED,
@@ -86,7 +87,7 @@ static void dr_msg_cb (rd_kafka_t *rk, const rd_kafka_message_t *rkmessage,
 
 
 
-int main_0068_produce_timeout (int argc, char **argv) {
+int main_0068_produce_timeout(int argc, char **argv) {
         rd_kafka_t *rk;
         const char *topic = test_mk_topic_name("0068_produce_timeout", 1);
         uint64_t testid;
@@ -101,19 +102,19 @@ int main_0068_produce_timeout (int argc, char **argv) {
         rd_kafka_conf_set_dr_msg_cb(conf, dr_msg_cb);
 
         test_socket_enable(conf);
-        test_curr->connect_cb = connect_cb;
+        test_curr->connect_cb  = connect_cb;
         test_curr->is_fatal_cb = is_fatal_cb;
 
-        rk = test_create_handle(RD_KAFKA_PRODUCER, conf);
-        rkt = test_create_producer_topic(rk, topic,
-                                         "message.timeout.ms", "2000", NULL);
+        rk  = test_create_handle(RD_KAFKA_PRODUCER, conf);
+        rkt = test_create_producer_topic(rk, topic, "message.timeout.ms",
+                                         "2000", NULL);
 
         TEST_SAY("Auto-creating topic %s\n", topic);
         test_auto_create_topic_rkt(rk, rkt, tmout_multip(5000));
 
         TEST_SAY("Producing %d messages that should timeout\n", msgcnt);
-        test_produce_msgs_nowait(rk, rkt, testid, 0, 0, msgcnt,
-                                 NULL, 0, 0, &msgcounter);
+        test_produce_msgs_nowait(rk, rkt, testid, 0, 0, msgcnt, NULL, 0, 0,
+                                 &msgcounter);
 
 
         TEST_SAY("Flushing..\n");
@@ -122,10 +123,10 @@ int main_0068_produce_timeout (int argc, char **argv) {
         TEST_SAY("%d/%d delivery reports, where of %d with proper error\n",
                  msg_dr_cnt, msgcnt, msg_dr_fail_cnt);
 
-        TEST_ASSERT(msg_dr_cnt == msgcnt,
-                    "expected %d, got %d", msgcnt, msg_dr_cnt);
-        TEST_ASSERT(msg_dr_fail_cnt == msgcnt,
-                    "expected %d, got %d", msgcnt, msg_dr_fail_cnt);
+        TEST_ASSERT(msg_dr_cnt == msgcnt, "expected %d, got %d", msgcnt,
+                    msg_dr_cnt);
+        TEST_ASSERT(msg_dr_fail_cnt == msgcnt, "expected %d, got %d", msgcnt,
+                    msg_dr_fail_cnt);
 
         rd_kafka_topic_destroy(rkt);
         rd_kafka_destroy(rk);
