@@ -45,8 +45,9 @@ struct expect {
 /**
  * @brief returns the message id
  */
-static int expect_check (const char *what, const struct expect *expected,
-                          const rd_kafka_message_t *rkmessage) {
+static int expect_check(const char *what,
+                        const struct expect *expected,
+                        const rd_kafka_message_t *rkmessage) {
         const struct expect *exp;
         rd_kafka_resp_err_t err;
         size_t idx = 0;
@@ -57,7 +58,7 @@ static int expect_check (const char *what, const struct expect *expected,
         int msgid;
 
         if (rkmessage->len != sizeof(msgid))
-                TEST_FAIL("%s: expected message len %"PRIusz" == sizeof(int)",
+                TEST_FAIL("%s: expected message len %" PRIusz " == sizeof(int)",
                           what, rkmessage->len);
 
         memcpy(&msgid, rkmessage->payload, rkmessage->len);
@@ -75,20 +76,20 @@ static int expect_check (const char *what, const struct expect *expected,
 
         /* msgid should always be first and has a variable value so hard to
          * match with the expect struct. */
-        for (idx = 0, exp = expected ;
-             !rd_kafka_header_get_all(hdrs, idx, &name,
-                                      (const void **)&value, &size) ;
+        for (idx = 0, exp = expected; !rd_kafka_header_get_all(
+                 hdrs, idx, &name, (const void **)&value, &size);
              idx++, exp++) {
 
-                TEST_SAYL(3, "%s: Msg #%d: "
-                          "Header #%"PRIusz": %s='%s' (expecting %s='%s')\n",
+                TEST_SAYL(3,
+                          "%s: Msg #%d: "
+                          "Header #%" PRIusz ": %s='%s' (expecting %s='%s')\n",
                           what, msgid, idx, name, value ? value : "(NULL)",
                           exp->name, exp->value ? exp->value : "(NULL)");
 
                 if (strcmp(name, exp->name))
-                        TEST_FAIL("%s: Expected header %s at idx #%"PRIusz
+                        TEST_FAIL("%s: Expected header %s at idx #%" PRIusz
                                   ", not %s",
-                                  what, exp->name, idx-1, name);
+                                  what, exp->name, idx - 1, name);
 
                 if (!strcmp(name, "msgid")) {
                         int vid;
@@ -96,10 +97,11 @@ static int expect_check (const char *what, const struct expect *expected,
                         /* Special handling: compare msgid header value
                          * to message body, should be identical */
                         if (size != rkmessage->len || size != sizeof(int))
-                                TEST_FAIL("%s: "
-                                          "Expected msgid/int-sized payload "
-                                          "%"PRIusz", got %"PRIusz,
-                                          what, size, rkmessage->len);
+                                TEST_FAIL(
+                                    "%s: "
+                                    "Expected msgid/int-sized payload "
+                                    "%" PRIusz ", got %" PRIusz,
+                                    what, size, rkmessage->len);
 
                         /* Copy to avoid unaligned access (by cast) */
                         memcpy(&vid, value, size);
@@ -109,8 +111,8 @@ static int expect_check (const char *what, const struct expect *expected,
                                           what, vid, msgid);
 
                         if (exp_msgid != vid)
-                                TEST_FAIL("%s: Expected msgid %d, not %d",
-                                          what, exp_msgid, vid);
+                                TEST_FAIL("%s: Expected msgid %d, not %d", what,
+                                          exp_msgid, vid);
                         continue;
                 }
 
@@ -127,8 +129,9 @@ static int expect_check (const char *what, const struct expect *expected,
                                     what, exp->name);
 
                         TEST_ASSERT(size == strlen(exp->value),
-                                    "%s: Expected size %"PRIusz" for %s, "
-                                    "not %"PRIusz,
+                                    "%s: Expected size %" PRIusz
+                                    " for %s, "
+                                    "not %" PRIusz,
                                     what, strlen(exp->value), exp->name, size);
 
                         TEST_ASSERT(value[size] == '\0',
@@ -155,25 +158,16 @@ static int expect_check (const char *what, const struct expect *expected,
 /**
  * @brief Delivery report callback
  */
-static void dr_msg_cb (rd_kafka_t *rk,
-                       const rd_kafka_message_t *rkmessage, void *opaque) {
+static void
+dr_msg_cb(rd_kafka_t *rk, const rd_kafka_message_t *rkmessage, void *opaque) {
         const struct expect expected[] = {
-                { "msgid", NULL }, /* special handling */
-                { "static", "hey" },
-                { "null", NULL },
-                { "empty", "" },
-                { "send1", "1" },
-                { "multi", "multi5" },
-                { NULL }
-        };
+            {"msgid", NULL}, /* special handling */
+            {"static", "hey"}, {"null", NULL},      {"empty", ""},
+            {"send1", "1"},    {"multi", "multi5"}, {NULL}};
         const struct expect replace_expected[] = {
-                { "msgid", NULL },
-                { "new", "one" },
-                { "this is the", NULL },
-                { "replaced headers\"", "" },
-                { "new", "right?" },
-                { NULL }
-        };
+            {"msgid", NULL},       {"new", "one"},
+            {"this is the", NULL}, {"replaced headers\"", ""},
+            {"new", "right?"},     {NULL}};
         const struct expect *exp;
         rd_kafka_headers_t *new_hdrs;
         int msgid;
@@ -187,11 +181,11 @@ static void dr_msg_cb (rd_kafka_t *rk,
         /* Replace entire headers list */
         if (msgid > 0) {
                 new_hdrs = rd_kafka_headers_new(1);
-                rd_kafka_header_add(new_hdrs, "msgid", -1,
-                                    &msgid, sizeof(msgid));
-                for (exp = &replace_expected[1] ; exp->name ; exp++)
-                        rd_kafka_header_add(new_hdrs,
-                                            exp->name, -1, exp->value, -1);
+                rd_kafka_header_add(new_hdrs, "msgid", -1, &msgid,
+                                    sizeof(msgid));
+                for (exp = &replace_expected[1]; exp->name; exp++)
+                        rd_kafka_header_add(new_hdrs, exp->name, -1, exp->value,
+                                            -1);
 
                 rd_kafka_message_set_headers((rd_kafka_message_t *)rkmessage,
                                              new_hdrs);
@@ -200,37 +194,41 @@ static void dr_msg_cb (rd_kafka_t *rk,
         }
 
         exp_msgid++;
-
 }
 
-static void expect_iter (const char *what,
-                         const rd_kafka_headers_t *hdrs, const char *name,
-                         const char **expected, size_t cnt) {
+static void expect_iter(const char *what,
+                        const rd_kafka_headers_t *hdrs,
+                        const char *name,
+                        const char **expected,
+                        size_t cnt) {
         size_t idx;
         rd_kafka_resp_err_t err;
         const void *value;
         size_t size;
 
-        for (idx = 0 ;
-             !(err = rd_kafka_header_get(hdrs, idx, name, &value, &size)) ;\
+        for (idx = 0;
+             !(err = rd_kafka_header_get(hdrs, idx, name, &value, &size));
              idx++) {
                 TEST_ASSERT(idx < cnt,
                             "%s: too many headers matching '%s', "
-                            "expected %"PRIusz,
+                            "expected %" PRIusz,
                             what, name, cnt);
-                TEST_SAYL(3, "%s: get(%"PRIusz", '%s') "
+                TEST_SAYL(3,
+                          "%s: get(%" PRIusz
+                          ", '%s') "
                           "expecting '%s' =? '%s'\n",
                           what, idx, name, expected[idx], (const char *)value);
 
 
-                TEST_ASSERT(!strcmp((const char *)value, expected[idx]),
-                            "%s: get(%"PRIusz", '%s') expected '%s', not '%s'",
-                            what, idx, name, expected[idx],
-                            (const char *)value);
+                TEST_ASSERT(
+                    !strcmp((const char *)value, expected[idx]),
+                    "%s: get(%" PRIusz ", '%s') expected '%s', not '%s'", what,
+                    idx, name, expected[idx], (const char *)value);
         }
 
         TEST_ASSERT(idx == cnt,
-                    "%s: expected %"PRIusz" headers matching '%s', not %"PRIusz,
+                    "%s: expected %" PRIusz
+                    " headers matching '%s', not %" PRIusz,
                     what, cnt, name, idx);
 }
 
@@ -239,28 +237,21 @@ static void expect_iter (const char *what,
 /**
  * @brief First on_send() interceptor
  */
-static rd_kafka_resp_err_t on_send1 (rd_kafka_t *rk,
-                                     rd_kafka_message_t *rkmessage,
-                                     void *ic_opaque) {
+static rd_kafka_resp_err_t
+on_send1(rd_kafka_t *rk, rd_kafka_message_t *rkmessage, void *ic_opaque) {
         const struct expect expected[] = {
-                { "msgid", NULL }, /* special handling */
-                { "static", "hey" },
-                { "multi", "multi1" },
-                { "multi", "multi2" },
-                { "multi", "multi3" },
-                { "null", NULL },
-                { "empty", "" },
-                { NULL }
-        };
+            {"msgid", NULL}, /* special handling */
+            {"static", "hey"},
+            {"multi", "multi1"},
+            {"multi", "multi2"},
+            {"multi", "multi3"},
+            {"null", NULL},
+            {"empty", ""},
+            {NULL}};
         const char *expect_iter_multi[4] = {
-                "multi1",
-                "multi2",
-                "multi3",
-                "multi4" /* added below */
-        };
-        const char *expect_iter_static[1] = {
-                "hey"
+            "multi1", "multi2", "multi3", "multi4" /* added below */
         };
+        const char *expect_iter_static[1] = {"hey"};
         rd_kafka_headers_t *hdrs;
         size_t header_cnt;
         rd_kafka_resp_err_t err;
@@ -274,14 +265,14 @@ static rd_kafka_resp_err_t on_send1 (rd_kafka_t *rk,
                 return RD_KAFKA_RESP_ERR_NO_ERROR;
 
         header_cnt = rd_kafka_header_cnt(hdrs);
-        TEST_ASSERT(header_cnt == 7,
-                    "Expected 7 length got %"PRIusz"", header_cnt);
+        TEST_ASSERT(header_cnt == 7, "Expected 7 length got %" PRIusz "",
+                    header_cnt);
 
         rd_kafka_header_add(hdrs, "multi", -1, "multi4", -1);
 
         header_cnt = rd_kafka_header_cnt(hdrs);
-        TEST_ASSERT(header_cnt == 8,
-                    "Expected 8 length got %"PRIusz"", header_cnt);
+        TEST_ASSERT(header_cnt == 8, "Expected 8 length got %" PRIusz "",
+                    header_cnt);
 
         /* test iter() */
         expect_iter(__FUNCTION__, hdrs, "multi", expect_iter_multi, 4);
@@ -291,28 +282,27 @@ static rd_kafka_resp_err_t on_send1 (rd_kafka_t *rk,
         rd_kafka_header_add(hdrs, "send1", -1, "1", -1);
 
         header_cnt = rd_kafka_header_cnt(hdrs);
-        TEST_ASSERT(header_cnt == 9,
-                    "Expected 9 length got %"PRIusz"", header_cnt);
+        TEST_ASSERT(header_cnt == 9, "Expected 9 length got %" PRIusz "",
+                    header_cnt);
 
         rd_kafka_header_remove(hdrs, "multi");
 
         header_cnt = rd_kafka_header_cnt(hdrs);
-        TEST_ASSERT(header_cnt == 5,
-                    "Expected 5 length got %"PRIusz"", header_cnt);
+        TEST_ASSERT(header_cnt == 5, "Expected 5 length got %" PRIusz "",
+                    header_cnt);
 
         rd_kafka_header_add(hdrs, "multi", -1, "multi5", -1);
 
         header_cnt = rd_kafka_header_cnt(hdrs);
-        TEST_ASSERT(header_cnt == 6,
-                    "Expected 6 length got %"PRIusz"", header_cnt);
+        TEST_ASSERT(header_cnt == 6, "Expected 6 length got %" PRIusz "",
+                    header_cnt);
 
         /* test get_last() */
         err = rd_kafka_header_get_last(hdrs, "multi", &value, &size);
         TEST_ASSERT(!err, "%s", rd_kafka_err2str(err));
         TEST_ASSERT(size == strlen("multi5") &&
-                    !strcmp((const char *)value, "multi5"),
-                    "expected 'multi5', not '%s'",
-                    (const char *)value);
+                        !strcmp((const char *)value, "multi5"),
+                    "expected 'multi5', not '%s'", (const char *)value);
 
         return RD_KAFKA_RESP_ERR_NO_ERROR;
 }
@@ -321,18 +311,12 @@ static rd_kafka_resp_err_t on_send1 (rd_kafka_t *rk,
 /**
  * @brief Second on_send() interceptor
  */
-static rd_kafka_resp_err_t on_send2 (rd_kafka_t *rk,
-                                     rd_kafka_message_t *rkmessage,
-                                     void *ic_opaque) {
+static rd_kafka_resp_err_t
+on_send2(rd_kafka_t *rk, rd_kafka_message_t *rkmessage, void *ic_opaque) {
         const struct expect expected[] = {
-                { "msgid", NULL }, /* special handling */
-                { "static", "hey" },
-                { "null", NULL },
-                { "empty", "" },
-                { "send1", "1" },
-                { "multi", "multi5" },
-                { NULL }
-        };
+            {"msgid", NULL}, /* special handling */
+            {"static", "hey"}, {"null", NULL},      {"empty", ""},
+            {"send1", "1"},    {"multi", "multi5"}, {NULL}};
 
         expect_check(__FUNCTION__, expected, rkmessage);
 
@@ -343,16 +327,18 @@ static rd_kafka_resp_err_t on_send2 (rd_kafka_t *rk,
  * @brief on_new() interceptor to set up message interceptors
  *        from rd_kafka_new().
  */
-static rd_kafka_resp_err_t on_new (rd_kafka_t *rk, const rd_kafka_conf_t *conf,
-                                   void *ic_opaque,
-                                   char *errstr, size_t errstr_size) {
+static rd_kafka_resp_err_t on_new(rd_kafka_t *rk,
+                                  const rd_kafka_conf_t *conf,
+                                  void *ic_opaque,
+                                  char *errstr,
+                                  size_t errstr_size) {
         rd_kafka_interceptor_add_on_send(rk, __FILE__, on_send1, NULL);
         rd_kafka_interceptor_add_on_send(rk, __FILE__, on_send2, NULL);
         return RD_KAFKA_RESP_ERR_NO_ERROR;
 }
 
 
-int main_0072_headers_ut (int argc, char **argv) {
+int main_0072_headers_ut(int argc, char **argv) {
         const char *topic = test_mk_topic_name(__FUNCTION__ + 5, 0);
         rd_kafka_t *rk;
         rd_kafka_conf_t *conf;
@@ -370,25 +356,22 @@ int main_0072_headers_ut (int argc, char **argv) {
         rk = test_create_handle(RD_KAFKA_PRODUCER, conf);
 
         /* First message is without headers (negative testing) */
-        i = 0;
+        i   = 0;
         err = rd_kafka_producev(
-                rk,
-                RD_KAFKA_V_TOPIC(topic),
-                RD_KAFKA_V_VALUE(&i, sizeof(i)),
-                RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY),
-                RD_KAFKA_V_END);
-        TEST_ASSERT(!err,
-                    "producev() failed: %s", rd_kafka_err2str(err));
+            rk, RD_KAFKA_V_TOPIC(topic), RD_KAFKA_V_VALUE(&i, sizeof(i)),
+            RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY), RD_KAFKA_V_END);
+        TEST_ASSERT(!err, "producev() failed: %s", rd_kafka_err2str(err));
         exp_msgid++;
 
-        for (i = 1 ; i < msgcnt ; i++, exp_msgid++) {
+        for (i = 1; i < msgcnt; i++, exp_msgid++) {
                 /* Use headers list on one message */
                 if (i == 3) {
                         rd_kafka_headers_t *hdrs = rd_kafka_headers_new(4);
 
                         header_cnt = rd_kafka_header_cnt(hdrs);
                         TEST_ASSERT(header_cnt == 0,
-                                    "Expected 0 length got %"PRIusz"", header_cnt);
+                                    "Expected 0 length got %" PRIusz "",
+                                    header_cnt);
 
                         rd_kafka_headers_t *copied;
 
@@ -396,7 +379,8 @@ int main_0072_headers_ut (int argc, char **argv) {
                         rd_kafka_header_add(hdrs, "static", -1, "hey", -1);
                         rd_kafka_header_add(hdrs, "multi", -1, "multi1", -1);
                         rd_kafka_header_add(hdrs, "multi", -1, "multi2", 6);
-                        rd_kafka_header_add(hdrs, "multi", -1, "multi3", strlen("multi3"));
+                        rd_kafka_header_add(hdrs, "multi", -1, "multi3",
+                                            strlen("multi3"));
                         rd_kafka_header_add(hdrs, "null", -1, NULL, 0);
 
                         /* Make a copy of the headers to verify copy() */
@@ -404,7 +388,8 @@ int main_0072_headers_ut (int argc, char **argv) {
 
                         header_cnt = rd_kafka_header_cnt(hdrs);
                         TEST_ASSERT(header_cnt == 6,
-                                    "Expected 6 length got %"PRIusz"", header_cnt);
+                                    "Expected 6 length got %" PRIusz "",
+                                    header_cnt);
 
                         rd_kafka_headers_destroy(hdrs);
 
@@ -413,14 +398,12 @@ int main_0072_headers_ut (int argc, char **argv) {
                         /* Try unsupported _V_HEADER() and _V_HEADERS() mix,
                          * must fail with CONFLICT */
                         err = rd_kafka_producev(
-                                rk,
-                                RD_KAFKA_V_TOPIC(topic),
-                                RD_KAFKA_V_VALUE(&i, sizeof(i)),
-                                RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY),
-                                RD_KAFKA_V_HEADER("will_be_removed", "yep", -1),
-                                RD_KAFKA_V_HEADERS(copied),
-                                RD_KAFKA_V_HEADER("empty", "", 0),
-                                RD_KAFKA_V_END);
+                            rk, RD_KAFKA_V_TOPIC(topic),
+                            RD_KAFKA_V_VALUE(&i, sizeof(i)),
+                            RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY),
+                            RD_KAFKA_V_HEADER("will_be_removed", "yep", -1),
+                            RD_KAFKA_V_HEADERS(copied),
+                            RD_KAFKA_V_HEADER("empty", "", 0), RD_KAFKA_V_END);
                         TEST_ASSERT(err == RD_KAFKA_RESP_ERR__CONFLICT,
                                     "producev(): expected CONFLICT, got %s",
                                     rd_kafka_err2str(err));
@@ -428,31 +411,28 @@ int main_0072_headers_ut (int argc, char **argv) {
                         /* Proper call using only _V_HEADERS() */
                         rd_kafka_header_add(copied, "empty", -1, "", -1);
                         err = rd_kafka_producev(
-                                rk,
-                                RD_KAFKA_V_TOPIC(topic),
-                                RD_KAFKA_V_VALUE(&i, sizeof(i)),
-                                RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY),
-                                RD_KAFKA_V_HEADERS(copied),
-                                RD_KAFKA_V_END);
+                            rk, RD_KAFKA_V_TOPIC(topic),
+                            RD_KAFKA_V_VALUE(&i, sizeof(i)),
+                            RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY),
+                            RD_KAFKA_V_HEADERS(copied), RD_KAFKA_V_END);
                         TEST_ASSERT(!err, "producev() failed: %s",
                                     rd_kafka_err2str(err));
 
                 } else {
                         err = rd_kafka_producev(
-                                rk,
-                                RD_KAFKA_V_TOPIC(topic),
-                                RD_KAFKA_V_VALUE(&i, sizeof(i)),
-                                RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY),
-                                RD_KAFKA_V_HEADER("msgid", &i, sizeof(i)),
-                                RD_KAFKA_V_HEADER("static", "hey", -1),
-                                RD_KAFKA_V_HEADER("multi", "multi1", -1),
-                                RD_KAFKA_V_HEADER("multi", "multi2", 6),
-                                RD_KAFKA_V_HEADER("multi", "multi3", strlen("multi3")),
-                                RD_KAFKA_V_HEADER("null", NULL, 0),
-                                RD_KAFKA_V_HEADER("empty", "", 0),
-                                RD_KAFKA_V_END);
-                        TEST_ASSERT(!err,
-                                    "producev() failed: %s", rd_kafka_err2str(err));
+                            rk, RD_KAFKA_V_TOPIC(topic),
+                            RD_KAFKA_V_VALUE(&i, sizeof(i)),
+                            RD_KAFKA_V_MSGFLAGS(RD_KAFKA_MSG_F_COPY),
+                            RD_KAFKA_V_HEADER("msgid", &i, sizeof(i)),
+                            RD_KAFKA_V_HEADER("static", "hey", -1),
+                            RD_KAFKA_V_HEADER("multi", "multi1", -1),
+                            RD_KAFKA_V_HEADER("multi", "multi2", 6),
+                            RD_KAFKA_V_HEADER("multi", "multi3",
+                                              strlen("multi3")),
+                            RD_KAFKA_V_HEADER("null", NULL, 0),
+                            RD_KAFKA_V_HEADER("empty", "", 0), RD_KAFKA_V_END);
+                        TEST_ASSERT(!err, "producev() failed: %s",
+                                    rd_kafka_err2str(err));
                 }
         }
 
