@@ -44,14 +44,13 @@
 /**
  * @brief Test producer handling (retry) of ERR_KAFKA_STORAGE_ERROR.
  */
-static void do_test_producer_storage_error (rd_bool_t too_few_retries) {
+static void do_test_producer_storage_error(rd_bool_t too_few_retries) {
         rd_kafka_conf_t *conf;
         rd_kafka_t *rk;
         rd_kafka_mock_cluster_t *mcluster;
         rd_kafka_resp_err_t err;
 
-        SUB_TEST_QUICK("%s",
-                       too_few_retries ? "with too few retries" : "");
+        SUB_TEST_QUICK("%s", too_few_retries ? "with too few retries" : "");
 
         test_conf_init(&conf, NULL, 10);
 
@@ -65,7 +64,7 @@ static void do_test_producer_storage_error (rd_bool_t too_few_retries) {
                 test_curr->exp_dr_err = RD_KAFKA_RESP_ERR_KAFKA_STORAGE_ERROR;
                 test_curr->exp_dr_status = RD_KAFKA_MSG_STATUS_NOT_PERSISTED;
         } else {
-                test_curr->exp_dr_err = RD_KAFKA_RESP_ERR_NO_ERROR;
+                test_curr->exp_dr_err    = RD_KAFKA_RESP_ERR_NO_ERROR;
                 test_curr->exp_dr_status = RD_KAFKA_MSG_STATUS_PERSISTED;
         }
 
@@ -75,17 +74,13 @@ static void do_test_producer_storage_error (rd_bool_t too_few_retries) {
         TEST_ASSERT(mcluster, "missing mock cluster");
 
         rd_kafka_mock_push_request_errors(
-                mcluster,
-                RD_KAFKAP_Produce,
-                3,
-                RD_KAFKA_RESP_ERR_KAFKA_STORAGE_ERROR,
-                RD_KAFKA_RESP_ERR_KAFKA_STORAGE_ERROR,
-                RD_KAFKA_RESP_ERR_KAFKA_STORAGE_ERROR);
+            mcluster, RD_KAFKAP_Produce, 3,
+            RD_KAFKA_RESP_ERR_KAFKA_STORAGE_ERROR,
+            RD_KAFKA_RESP_ERR_KAFKA_STORAGE_ERROR,
+            RD_KAFKA_RESP_ERR_KAFKA_STORAGE_ERROR);
 
-        err = rd_kafka_producev(rk,
-                                RD_KAFKA_V_TOPIC("mytopic"),
-                                RD_KAFKA_V_VALUE("hi", 2),
-                                RD_KAFKA_V_END);
+        err = rd_kafka_producev(rk, RD_KAFKA_V_TOPIC("mytopic"),
+                                RD_KAFKA_V_VALUE("hi", 2), RD_KAFKA_V_END);
         TEST_ASSERT(!err, "produce failed: %s", rd_kafka_err2str(err));
 
         /* Wait for delivery report. */
@@ -102,13 +97,13 @@ static void do_test_producer_storage_error (rd_bool_t too_few_retries) {
  *        RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS and then causing fetchers
  *        to not start.
  */
-static void do_test_offset_commit_error_during_rebalance (void) {
+static void do_test_offset_commit_error_during_rebalance(void) {
         rd_kafka_conf_t *conf;
         rd_kafka_t *c1, *c2;
         rd_kafka_mock_cluster_t *mcluster;
         const char *bootstraps;
         const char *topic = "test";
-        const int msgcnt = 100;
+        const int msgcnt  = 100;
         rd_kafka_resp_err_t err;
 
         SUB_TEST();
@@ -122,8 +117,7 @@ static void do_test_offset_commit_error_during_rebalance (void) {
         /* Seed the topic with messages */
         test_produce_msgs_easy_v(topic, 0, RD_KAFKA_PARTITION_UA, 0, msgcnt, 10,
                                  "bootstrap.servers", bootstraps,
-                                 "batch.num.messages", "1",
-                                 NULL);
+                                 "batch.num.messages", "1", NULL);
 
         test_conf_set(conf, "bootstrap.servers", bootstraps);
         test_conf_set(conf, "auto.offset.reset", "earliest");
@@ -135,8 +129,7 @@ static void do_test_offset_commit_error_during_rebalance (void) {
         c1 = test_create_consumer("mygroup", test_rebalance_cb,
                                   rd_kafka_conf_dup(conf), NULL);
 
-        c2 = test_create_consumer("mygroup", test_rebalance_cb,
-                                  conf, NULL);
+        c2 = test_create_consumer("mygroup", test_rebalance_cb, conf, NULL);
 
         test_consumer_subscribe(c1, topic);
         test_consumer_subscribe(c2, topic);
@@ -151,23 +144,22 @@ static void do_test_offset_commit_error_during_rebalance (void) {
         rd_kafka_destroy(c2);
 
         rd_kafka_mock_push_request_errors(
-                mcluster,
-                RD_KAFKAP_OffsetCommit,
-                6,
-                RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
-                RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
-                RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
-                RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
-                RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
-                RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS);
+            mcluster, RD_KAFKAP_OffsetCommit, 6,
+            RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
+            RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
+            RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
+            RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
+            RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
+            RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS);
 
         /* This commit should fail (async) */
         TEST_SAY("Committing (should fail)\n");
-        err = rd_kafka_commit(c1, NULL, 0/*sync*/);
+        err = rd_kafka_commit(c1, NULL, 0 /*sync*/);
         TEST_SAY("Commit returned %s\n", rd_kafka_err2name(err));
         TEST_ASSERT(err == RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS,
                     "Expected commit to fail with ERR_REBALANCE_IN_PROGRESS, "
-                    "not %s", rd_kafka_err2name(err));
+                    "not %s",
+                    rd_kafka_err2name(err));
 
         /* Wait for new assignment and able to read all messages */
         test_consumer_poll("C1.PRE", c1, 0, -1, -1, msgcnt, NULL);
@@ -186,16 +178,16 @@ static void do_test_offset_commit_error_during_rebalance (void) {
  *        RD_KAFKA_RESP_ERR_REBALANCE_IN_PROGRESS and then causing fetchers
  *        to not start.
  */
-static void do_test_offset_commit_request_timed_out (rd_bool_t auto_commit) {
+static void do_test_offset_commit_request_timed_out(rd_bool_t auto_commit) {
         rd_kafka_conf_t *conf;
         rd_kafka_t *c1, *c2;
         rd_kafka_mock_cluster_t *mcluster;
         const char *bootstraps;
         const char *topic = "test";
-        const int msgcnt = 1;
+        const int msgcnt  = 1;
         rd_kafka_topic_partition_list_t *partitions;
 
-        SUB_TEST_QUICK("enable.auto.commit=%s", auto_commit ? "true": "false");
+        SUB_TEST_QUICK("enable.auto.commit=%s", auto_commit ? "true" : "false");
 
         test_conf_init(&conf, NULL, 60);
 
@@ -206,20 +198,20 @@ static void do_test_offset_commit_request_timed_out (rd_bool_t auto_commit) {
         /* Seed the topic with messages */
         test_produce_msgs_easy_v(topic, 0, RD_KAFKA_PARTITION_UA, 0, msgcnt, 10,
                                  "bootstrap.servers", bootstraps,
-                                 "batch.num.messages", "1",
-                                 NULL);
+                                 "batch.num.messages", "1", NULL);
 
         test_conf_set(conf, "bootstrap.servers", bootstraps);
         test_conf_set(conf, "auto.offset.reset", "earliest");
-        test_conf_set(conf, "enable.auto.commit", auto_commit ? "true":"false");
+        test_conf_set(conf, "enable.auto.commit",
+                      auto_commit ? "true" : "false");
         /* Too high to be done by interval in this test */
         test_conf_set(conf, "auto.commit.interval.ms", "90000");
 
         /* Make sure we don't consume the entire partition in one Fetch */
         test_conf_set(conf, "fetch.message.max.bytes", "100");
 
-        c1 = test_create_consumer("mygroup", NULL,
-                                  rd_kafka_conf_dup(conf), NULL);
+        c1 = test_create_consumer("mygroup", NULL, rd_kafka_conf_dup(conf),
+                                  NULL);
 
 
         test_consumer_subscribe(c1, topic);
@@ -227,15 +219,12 @@ static void do_test_offset_commit_request_timed_out (rd_bool_t auto_commit) {
         /* Wait for assignment and one message */
         test_consumer_poll("C1.PRE", c1, 0, -1, -1, 1, NULL);
 
-        rd_kafka_mock_push_request_errors(
-                mcluster,
-                RD_KAFKAP_OffsetCommit,
-                2,
-                RD_KAFKA_RESP_ERR_REQUEST_TIMED_OUT,
-                RD_KAFKA_RESP_ERR_REQUEST_TIMED_OUT);
+        rd_kafka_mock_push_request_errors(mcluster, RD_KAFKAP_OffsetCommit, 2,
+                                          RD_KAFKA_RESP_ERR_REQUEST_TIMED_OUT,
+                                          RD_KAFKA_RESP_ERR_REQUEST_TIMED_OUT);
 
         if (!auto_commit)
-                TEST_CALL_ERR__(rd_kafka_commit(c1, NULL, 0/*sync*/));
+                TEST_CALL_ERR__(rd_kafka_commit(c1, NULL, 0 /*sync*/));
 
         /* Rely on consumer_close() doing final commit
          * when auto commit is enabled */
@@ -250,11 +239,11 @@ static void do_test_offset_commit_request_timed_out (rd_bool_t auto_commit) {
 
         partitions = rd_kafka_topic_partition_list_new(1);
         rd_kafka_topic_partition_list_add(partitions, topic, 0)->offset =
-                RD_KAFKA_OFFSET_INVALID;
+            RD_KAFKA_OFFSET_INVALID;
 
-        TEST_CALL_ERR__(rd_kafka_committed(c2, partitions, 10*1000));
+        TEST_CALL_ERR__(rd_kafka_committed(c2, partitions, 10 * 1000));
         TEST_ASSERT(partitions->elems[0].offset == 1,
-                    "Expected committed offset to be 1, not %"PRId64,
+                    "Expected committed offset to be 1, not %" PRId64,
                     partitions->elems[0].offset);
 
         rd_kafka_topic_partition_list_destroy(partitions);
@@ -266,6 +255,54 @@ static void do_test_offset_commit_request_timed_out (rd_bool_t auto_commit) {
         SUB_TEST_PASS();
 }
 
+/**
+ * @brief Verify that a cluster roll does not cause consumer_poll() to return
+ * the temporary and retriable COORDINATOR_LOAD_IN_PROGRESS error. We should
+ * backoff and retry in that case.
+ */
+static void do_test_joingroup_coordinator_load_in_progress() {
+        rd_kafka_conf_t *conf;
+        rd_kafka_t *consumer;
+        rd_kafka_mock_cluster_t *mcluster;
+        const char *bootstraps;
+        const char *topic = "test";
+        const int msgcnt  = 1;
+
+        SUB_TEST();
+
+        test_conf_init(&conf, NULL, 60);
+
+        mcluster = test_mock_cluster_new(1, &bootstraps);
+
+        rd_kafka_mock_topic_create(mcluster, topic, 1, 1);
+
+        test_produce_msgs_easy_v(topic, 0, RD_KAFKA_PARTITION_UA, 0, msgcnt, 10,
+                                 "bootstrap.servers", bootstraps,
+                                 "batch.num.messages", "1", NULL);
+
+        test_conf_set(conf, "bootstrap.servers", bootstraps);
+        test_conf_set(conf, "auto.offset.reset", "earliest");
+
+        rd_kafka_mock_push_request_errors(
+            mcluster, RD_KAFKAP_FindCoordinator, 1,
+            RD_KAFKA_RESP_ERR_COORDINATOR_LOAD_IN_PROGRESS);
+
+        consumer = test_create_consumer("mygroup", NULL, conf, NULL);
+
+        test_consumer_subscribe(consumer, topic);
+
+        /* Wait for assignment and one message */
+        test_consumer_poll("consumer", consumer, 0, -1, -1, msgcnt, NULL);
+
+        test_consumer_close(consumer);
+
+        rd_kafka_destroy(consumer);
+
+        test_mock_cluster_destroy(mcluster);
+
+        SUB_TEST_PASS();
+}
+
 int main_0117_mock_errors(int argc, char **argv) {
 
         if (test_needs_auth()) {
@@ -281,5 +318,7 @@ int main_0117_mock_errors(int argc, char **argv) {
         do_test_offset_commit_request_timed_out(rd_true);
         do_test_offset_commit_request_timed_out(rd_false);
 
+        do_test_joingroup_coordinator_load_in_progress();
+
         return 0;
 }
