@@ -8,24 +8,24 @@
 #  trivup python module
 #  gradle in your PATH
 
-from cluster_testing import LibrdkafkaTestCluster, print_report_summary, read_scenario_conf
+from cluster_testing import (
+    LibrdkafkaTestCluster,
+    print_report_summary,
+    read_scenario_conf)
 from LibrdkafkaTestApp import LibrdkafkaTestApp
-from trivup.apps.ZookeeperApp import ZookeeperApp
-from trivup.apps.KafkaBrokerApp import KafkaBrokerApp
 
 import subprocess
-import time
 import tempfile
 import os
 import sys
 import argparse
 import json
-import tempfile
 
-def test_it (version, deploy=True, conf={}, rdkconf={}, tests=None,
-             interact=False, debug=False, scenario="default"):
+
+def test_it(version, deploy=True, conf={}, rdkconf={}, tests=None,
+            interact=False, debug=False, scenario="default"):
     """
-    @brief Create, deploy and start a Kafka cluster using Kafka \p version
+    @brief Create, deploy and start a Kafka cluster using Kafka \\p version
     Then run librdkafka's regression tests.
     """
 
@@ -34,7 +34,7 @@ def test_it (version, deploy=True, conf={}, rdkconf={}, tests=None,
                                     debug=debug, scenario=scenario)
 
     # librdkafka's regression tests, as an App.
-    _rdkconf = conf.copy() # Base rdkconf on cluster conf + rdkconf
+    _rdkconf = conf.copy()  # Base rdkconf on cluster conf + rdkconf
     _rdkconf.update(rdkconf)
     rdkafka = LibrdkafkaTestApp(cluster, version, _rdkconf, tests=tests,
                                 scenario=scenario)
@@ -46,22 +46,35 @@ def test_it (version, deploy=True, conf={}, rdkconf={}, tests=None,
     cluster.start(timeout=30)
 
     if conf.get('test_mode', '') == 'bash':
-        cmd = 'bash --rcfile <(cat ~/.bashrc; echo \'PS1="[TRIVUP:%s@%s] \\u@\\h:\w$ "\')' % (cluster.name, version)
-        subprocess.call(cmd, env=rdkafka.env, shell=True, executable='/bin/bash')
+        cmd = 'bash --rcfile <(cat ~/.bashrc; echo \'PS1="[TRIVUP:%s@%s] \\u@\\h:\\w$ "\')' % (  # noqa: E501
+            cluster.name, version)
+        subprocess.call(
+            cmd,
+            env=rdkafka.env,
+            shell=True,
+            executable='/bin/bash')
         report = None
 
     else:
         rdkafka.start()
-        print('# librdkafka regression tests started, logs in %s' % rdkafka.root_path())
-        rdkafka.wait_stopped(timeout=60*30)
+        print(
+            '# librdkafka regression tests started, logs in %s' %
+            rdkafka.root_path())
+        rdkafka.wait_stopped(timeout=60 * 30)
 
         report = rdkafka.report()
         report['root_path'] = rdkafka.root_path()
 
         if report.get('tests_failed', 0) > 0 and interact:
-            print('# Connect to cluster with bootstrap.servers %s' % cluster.bootstrap_servers())
-            print('# Exiting the shell will bring down the cluster. Good luck.')
-            subprocess.call('bash --rcfile <(cat ~/.bashrc; echo \'PS1="[TRIVUP:%s@%s] \\u@\\h:\w$ "\')' % (cluster.name, version), env=rdkafka.env, shell=True, executable='/bin/bash')
+            print(
+                '# Connect to cluster with bootstrap.servers %s' %
+                cluster.bootstrap_servers())
+            print('# Exiting the shell will bring down the cluster. '
+                  'Good luck.')
+            subprocess.call(
+                'bash --rcfile <(cat ~/.bashrc; echo \'PS1="[TRIVUP:%s@%s] \\u@\\h:\\w$ "\')' %  # noqa: E501
+                (cluster.name, version), env=rdkafka.env, shell=True,
+                executable='/bin/bash')
 
     cluster.stop(force=True)
 
@@ -69,7 +82,7 @@ def test_it (version, deploy=True, conf={}, rdkconf={}, tests=None,
     return report
 
 
-def handle_report (report, version, suite):
+def handle_report(report, version, suite):
     """ Parse test report and return tuple (Passed(bool), Reason(str)) """
     test_cnt = report.get('tests_run', 0)
 
@@ -78,35 +91,42 @@ def handle_report (report, version, suite):
 
     passed = report.get('tests_passed', 0)
     failed = report.get('tests_failed', 0)
-    if 'all' in suite.get('expect_fail', []) or version in suite.get('expect_fail', []):
+    if 'all' in suite.get('expect_fail', []) or version in suite.get(
+            'expect_fail', []):
         expect_fail = True
     else:
         expect_fail = False
 
     if expect_fail:
         if failed == test_cnt:
-            return (True, 'All %d/%d tests failed as expected' % (failed, test_cnt))
+            return (True, 'All %d/%d tests failed as expected' %
+                    (failed, test_cnt))
         else:
-            return (False, '%d/%d tests failed: expected all to fail' % (failed, test_cnt))
+            return (False, '%d/%d tests failed: expected all to fail' %
+                    (failed, test_cnt))
     else:
         if failed > 0:
-            return (False, '%d/%d tests passed: expected all to pass' % (passed, test_cnt))
+            return (False, '%d/%d tests passed: expected all to pass' %
+                    (passed, test_cnt))
         else:
-            return (True, 'All %d/%d tests passed as expected' % (passed, test_cnt))
-
+            return (True, 'All %d/%d tests passed as expected' %
+                    (passed, test_cnt))
 
 
 if __name__ == '__main__':
 
-    parser = argparse.ArgumentParser(description='Run librdkafka tests on a range of broker versions')
+    parser = argparse.ArgumentParser(
+        description='Run librdkafka tests on a range of broker versions')
 
     parser.add_argument('--debug', action='store_true', default=False,
                         help='Enable trivup debugging')
     parser.add_argument('--conf', type=str, dest='conf', default=None,
                         help='trivup JSON config object (not file)')
     parser.add_argument('--rdkconf', type=str, dest='rdkconf', default=None,
-                        help='trivup JSON config object (not file) for LibrdkafkaTestApp')
-    parser.add_argument('--scenario', type=str, dest='scenario', default='default',
+                        help='trivup JSON config object (not file) '
+                        'for LibrdkafkaTestApp')
+    parser.add_argument('--scenario', type=str, dest='scenario',
+                        default='default',
                         help='Test scenario (see scenarios/ directory)')
     parser.add_argument('--tests', type=str, dest='tests', default=None,
                         help='Test to run (e.g., "0002")')
@@ -114,20 +134,47 @@ if __name__ == '__main__':
                         help='Write test suites report to this filename')
     parser.add_argument('--interact', action='store_true', dest='interact',
                         default=False,
-                        help='On test failure start a shell before bringing the cluster down.')
+                        help='On test failure start a shell before bringing '
+                        'the cluster down.')
     parser.add_argument('versions', type=str, nargs='*',
                         default=['0.8.1.1', '0.8.2.2', '0.9.0.1', '2.3.0'],
                         help='Broker versions to test')
-    parser.add_argument('--interactive', action='store_true', dest='interactive',
+    parser.add_argument('--interactive', action='store_true',
+                        dest='interactive',
                         default=False,
                         help='Start a shell instead of running tests')
-    parser.add_argument('--root', type=str, default=os.environ.get('TRIVUP_ROOT', 'tmp'), help='Root working directory')
-    parser.add_argument('--port', default=None, help='Base TCP port to start allocating from')
-    parser.add_argument('--kafka-src', dest='kafka_path', type=str, default=None, help='Path to Kafka git repo checkout (used for version=trunk)')
-    parser.add_argument('--brokers', dest='broker_cnt', type=int, default=3, help='Number of Kafka brokers')
-    parser.add_argument('--ssl', dest='ssl', action='store_true', default=False,
+    parser.add_argument(
+        '--root',
+        type=str,
+        default=os.environ.get(
+            'TRIVUP_ROOT',
+            'tmp'),
+        help='Root working directory')
+    parser.add_argument(
+        '--port',
+        default=None,
+        help='Base TCP port to start allocating from')
+    parser.add_argument(
+        '--kafka-src',
+        dest='kafka_path',
+        type=str,
+        default=None,
+        help='Path to Kafka git repo checkout (used for version=trunk)')
+    parser.add_argument(
+        '--brokers',
+        dest='broker_cnt',
+        type=int,
+        default=3,
+        help='Number of Kafka brokers')
+    parser.add_argument('--ssl', dest='ssl', action='store_true',
+                        default=False,
                         help='Enable SSL endpoints')
-    parser.add_argument('--sasl', dest='sasl', type=str, default=None, help='SASL mechanism (PLAIN, GSSAPI)')
+    parser.add_argument(
+        '--sasl',
+        dest='sasl',
+        type=str,
+        default=None,
+        help='SASL mechanism (PLAIN, GSSAPI)')
 
     args = parser.parse_args()
 
@@ -189,7 +236,8 @@ if __name__ == '__main__':
             # Run tests
             print('#### Version %s, suite %s, scenario %s: STARTING' %
                   (version, suite['name'], args.scenario))
-            report = test_it(version, tests=tests, conf=_conf, rdkconf=_rdkconf,
+            report = test_it(version, tests=tests, conf=_conf,
+                             rdkconf=_rdkconf,
                              interact=args.interact, debug=args.debug,
                              scenario=args.scenario)
 
@@ -198,7 +246,7 @@ if __name__ == '__main__':
 
             # Handle test report
             report['version'] = version
-            passed,reason = handle_report(report, version, suite)
+            passed, reason = handle_report(report, version, suite)
             report['PASSED'] = passed
             report['REASON'] = reason
 
@@ -212,7 +260,12 @@ if __name__ == '__main__':
                 fail_cnt += 1
 
                 # Emit hopefully relevant parts of the log on failure
-                subprocess.call("grep --color=always -B100 -A10 FAIL %s" % (os.path.join(report['root_path'], 'stderr.log')), shell=True)
+                subprocess.call(
+                    "grep --color=always -B100 -A10 FAIL %s" %
+                    (os.path.join(
+                        report['root_path'],
+                        'stderr.log')),
+                    shell=True)
 
             print('#### Test output: %s/stderr.log' % (report['root_path']))
 
@@ -229,7 +282,7 @@ if __name__ == '__main__':
         f = os.fdopen(fd, 'w')
 
     full_report = {'suites': suites, 'pass_cnt': pass_cnt,
-                   'fail_cnt': fail_cnt, 'total_cnt': pass_cnt+fail_cnt}
+                   'fail_cnt': fail_cnt, 'total_cnt': pass_cnt + fail_cnt}
 
     f.write(json.dumps(full_report))
     f.close()
