@@ -7,20 +7,26 @@
 #  trivup python module
 #  gradle in your PATH
 
-from trivup.trivup import Cluster, UuidAllocator
+from trivup.trivup import Cluster
 from trivup.apps.ZookeeperApp import ZookeeperApp
 from trivup.apps.KafkaBrokerApp import KafkaBrokerApp
 from trivup.apps.KerberosKdcApp import KerberosKdcApp
 from trivup.apps.SslApp import SslApp
+from trivup.apps.OauthbearerOIDCApp import OauthbearerOIDCApp
 
-import os, sys, json, argparse, re
+import os
+import sys
+import json
+import argparse
+import re
 from jsoncomment import JsonComment
 
 
-def version_as_list (version):
+def version_as_list(version):
     if version == 'trunk':
-        return [sys.maxint]
-    return [int(a) for a in re.findall('\d+', version)][0:3]
+        return [sys.maxsize]
+    return [int(a) for a in re.findall('\\d+', version)][0:3]
+
 
 def read_scenario_conf(scenario):
     """ Read scenario configuration from scenarios/<scenario>.json """
@@ -28,20 +34,22 @@ def read_scenario_conf(scenario):
     with open(os.path.join('scenarios', scenario + '.json'), 'r') as f:
         return parser.load(f)
 
+
 class LibrdkafkaTestCluster(Cluster):
     def __init__(self, version, conf={}, num_brokers=3, debug=False,
                  scenario="default"):
         """
-        @brief Create, deploy and start a Kafka cluster using Kafka \p version
+        @brief Create, deploy and start a Kafka cluster using Kafka \\p version
 
-        Supported \p conf keys:
+        Supported \\p conf keys:
          * security.protocol - PLAINTEXT, SASL_PLAINTEXT, SASL_SSL
 
-        \p conf dict is passed to KafkaBrokerApp classes, etc.
+        \\p conf dict is passed to KafkaBrokerApp classes, etc.
         """
 
-        super(LibrdkafkaTestCluster, self).__init__(self.__class__.__name__,
-                                                    os.environ.get('TRIVUP_ROOT', 'tmp'), debug=debug)
+        super(LibrdkafkaTestCluster, self).__init__(
+            self.__class__.__name__,
+            os.environ.get('TRIVUP_ROOT', 'tmp'), debug=debug)
 
         # Read trivup config from scenario definition.
         defconf = read_scenario_conf(scenario)
@@ -63,6 +71,12 @@ class LibrdkafkaTestCluster(Cluster):
             # and keytabs are available at the time of Kafka config generation.
             kdc.start()
 
+        if 'OAUTHBEARER'.casefold() == \
+            defconf.get('sasl_mechanisms', "").casefold() and \
+                'OIDC'.casefold() == \
+                defconf.get('sasl_oauthbearer_method', "").casefold():
+            self.oidc = OauthbearerOIDCApp(self)
+
         # Brokers
         defconf.update({'replication_factor': min(num_brokers, 3),
                         'version': version,
@@ -70,19 +84,29 @@ class LibrdkafkaTestCluster(Cluster):
         self.conf = defconf
 
         for n in range(0, num_brokers):
-            # Configure rack & replica selector if broker supports fetch-from-follower
+            # Configure rack & replica selector if broker supports
+            # fetch-from-follower
             if version_as_list(version) >= [2, 4, 0]:
-                defconf.update({'conf': ['broker.rack=RACK${appid}', 'replica.selector.class=org.apache.kafka.common.replica.RackAwareReplicaSelector']})
+                defconf.update(
+                    {
+                        'conf': [
+                            'broker.rack=RACK${appid}',
+                            'replica.selector.class=org.apache.kafka.common.replica.RackAwareReplicaSelector']})  # noqa: E501
             self.brokers.append(KafkaBrokerApp(self, defconf))
 
-
-    def bootstrap_servers (self):
+    def bootstrap_servers(self):
         """ @return Kafka bootstrap servers based on security.protocol """
-        all_listeners = (','.join(self.get_all('advertised_listeners', '', KafkaBrokerApp))).split(',')
-        return ','.join([x for x in all_listeners if x.startswith(self.conf.get('security.protocol'))])
+        all_listeners = (
+            ','.join(
+                self.get_all(
+                    'advertised_listeners',
+                    '',
+                    KafkaBrokerApp))).split(',')
+        return ','.join([x for x in all_listeners if x.startswith(
+            self.conf.get('security.protocol'))])
 
 
-def result2color (res):
+def result2color(res):
     if res == 'PASSED':
         return '\033[42m'
     elif res == 'FAILED':
@@ -90,7 +114,8 @@ def result2color (res):
     else:
         return ''
 
-def print_test_report_summary (name, report):
+
+def print_test_report_summary(name, report):
     """ Print summary for a test run. """
     passed = report.get('PASSED', False)
     if passed:
@@ -101,12 +126,12 @@ def print_test_report_summary (name, report):
     print('%6s  %-50s: %s' % (resstr, name, report.get('REASON', 'n/a')))
     if not passed:
         # Print test details
-        for name,test in report.get('tests', {}).items():
+        for name, test in report.get('tests', {}).items():
             testres = test.get('state', '')
             if testres == 'SKIPPED':
                 continue
-            print('%s   --> %-20s \033[0m' % \
-                  ('%s%s\033[0m' % \
+            print('%s   --> %-20s \033[0m' %
+                  ('%s%s\033[0m' %
                    (result2color(test.get('state', 'n/a')),
                     test.get('state', 'n/a')),
                    test.get('name', 'n/a')))
@@ -114,14 +139,14 @@ def print_test_report_summary (name, report):
               ('', report.get('root_path', '.'), 'stderr.log'))
 
 
-def print_report_summary (fullreport):
+def print_report_summary(fullreport):
     """ Print summary from a full report suite """
     suites = fullreport.get('suites', list())
     print('#### Full test suite report (%d suite(s))' % len(suites))
     for suite in suites:
-        for version,report in suite.get('version', {}).items():
-            print_test_report_summary('%s @ %s' % \
-                                      (suite.get('name','n/a'), version),
+        for version, report in suite.get('version', {}).items():
+            print_test_report_summary('%s @ %s' %
+                                      (suite.get('name', 'n/a'), version),
                                       report)
 
     pass_cnt = fullreport.get('pass_cnt', -1)
@@ -136,11 +161,10 @@ def print_report_summary (fullreport):
     else:
         fail_clr = '\033[41m'
 
-    print('#### %d suites %sPASSED\033[0m, %d suites %sFAILED\033[0m' % \
+    print('#### %d suites %sPASSED\033[0m, %d suites %sFAILED\033[0m' %
           (pass_cnt, pass_clr, fail_cnt, fail_clr))
 
 
-
 if __name__ == '__main__':
 
     parser = argparse.ArgumentParser(description='Show test suite report')
